# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class GenerativefirewallIndividualRulesConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'off_topic': 'GenerativefirewallOffTopicRuleConfig',
        'pii_detection_input': 'GenerativefirewallPiiDetectionRuleConfig',
        'pii_detection_output': 'GenerativefirewallPiiDetectionRuleConfig',
        'token_counter_input': 'GenerativefirewallTokenCounterRuleConfig',
        'token_counter_output': 'GenerativefirewallTokenCounterRuleConfig',
        'unknown_external_source': 'GenerativefirewallUnknownExternalSourceRuleConfig',
        'language_detection': 'GenerativefirewallLanguageDetectionRuleConfig',
        'prompt_injection': 'GenerativefirewallPromptInjectionRuleConfig',
        'toxicity_rule_config_input': 'GenerativefirewallToxicityRuleConfig',
        'toxicity_rule_config_output': 'GenerativefirewallToxicityRuleConfig',
        'code_detection': 'GenerativefirewallCodeDetectionRuleConfig'
    }

    attribute_map = {
        'off_topic': 'offTopic',
        'pii_detection_input': 'piiDetectionInput',
        'pii_detection_output': 'piiDetectionOutput',
        'token_counter_input': 'tokenCounterInput',
        'token_counter_output': 'tokenCounterOutput',
        'unknown_external_source': 'unknownExternalSource',
        'language_detection': 'languageDetection',
        'prompt_injection': 'promptInjection',
        'toxicity_rule_config_input': 'toxicityRuleConfigInput',
        'toxicity_rule_config_output': 'toxicityRuleConfigOutput',
        'code_detection': 'codeDetection'
    }

    def __init__(self, off_topic=None, pii_detection_input=None, pii_detection_output=None, token_counter_input=None, token_counter_output=None, unknown_external_source=None, language_detection=None, prompt_injection=None, toxicity_rule_config_input=None, toxicity_rule_config_output=None, code_detection=None):  # noqa: E501
        """GenerativefirewallIndividualRulesConfig - a model defined in Swagger"""  # noqa: E501
        self._off_topic = None
        self._pii_detection_input = None
        self._pii_detection_output = None
        self._token_counter_input = None
        self._token_counter_output = None
        self._unknown_external_source = None
        self._language_detection = None
        self._prompt_injection = None
        self._toxicity_rule_config_input = None
        self._toxicity_rule_config_output = None
        self._code_detection = None
        self.discriminator = None
        if off_topic is not None:
            self.off_topic = off_topic
        if pii_detection_input is not None:
            self.pii_detection_input = pii_detection_input
        if pii_detection_output is not None:
            self.pii_detection_output = pii_detection_output
        if token_counter_input is not None:
            self.token_counter_input = token_counter_input
        if token_counter_output is not None:
            self.token_counter_output = token_counter_output
        if unknown_external_source is not None:
            self.unknown_external_source = unknown_external_source
        if language_detection is not None:
            self.language_detection = language_detection
        if prompt_injection is not None:
            self.prompt_injection = prompt_injection
        if toxicity_rule_config_input is not None:
            self.toxicity_rule_config_input = toxicity_rule_config_input
        if toxicity_rule_config_output is not None:
            self.toxicity_rule_config_output = toxicity_rule_config_output
        if code_detection is not None:
            self.code_detection = code_detection

    @property
    def off_topic(self):
        """Gets the off_topic of this GenerativefirewallIndividualRulesConfig.  # noqa: E501


        :return: The off_topic of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :rtype: GenerativefirewallOffTopicRuleConfig
        """
        return self._off_topic

    @off_topic.setter
    def off_topic(self, off_topic):
        """Sets the off_topic of this GenerativefirewallIndividualRulesConfig.


        :param off_topic: The off_topic of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :type: GenerativefirewallOffTopicRuleConfig
        """

        self._off_topic = off_topic

    @property
    def pii_detection_input(self):
        """Gets the pii_detection_input of this GenerativefirewallIndividualRulesConfig.  # noqa: E501


        :return: The pii_detection_input of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :rtype: GenerativefirewallPiiDetectionRuleConfig
        """
        return self._pii_detection_input

    @pii_detection_input.setter
    def pii_detection_input(self, pii_detection_input):
        """Sets the pii_detection_input of this GenerativefirewallIndividualRulesConfig.


        :param pii_detection_input: The pii_detection_input of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :type: GenerativefirewallPiiDetectionRuleConfig
        """

        self._pii_detection_input = pii_detection_input

    @property
    def pii_detection_output(self):
        """Gets the pii_detection_output of this GenerativefirewallIndividualRulesConfig.  # noqa: E501


        :return: The pii_detection_output of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :rtype: GenerativefirewallPiiDetectionRuleConfig
        """
        return self._pii_detection_output

    @pii_detection_output.setter
    def pii_detection_output(self, pii_detection_output):
        """Sets the pii_detection_output of this GenerativefirewallIndividualRulesConfig.


        :param pii_detection_output: The pii_detection_output of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :type: GenerativefirewallPiiDetectionRuleConfig
        """

        self._pii_detection_output = pii_detection_output

    @property
    def token_counter_input(self):
        """Gets the token_counter_input of this GenerativefirewallIndividualRulesConfig.  # noqa: E501


        :return: The token_counter_input of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :rtype: GenerativefirewallTokenCounterRuleConfig
        """
        return self._token_counter_input

    @token_counter_input.setter
    def token_counter_input(self, token_counter_input):
        """Sets the token_counter_input of this GenerativefirewallIndividualRulesConfig.


        :param token_counter_input: The token_counter_input of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :type: GenerativefirewallTokenCounterRuleConfig
        """

        self._token_counter_input = token_counter_input

    @property
    def token_counter_output(self):
        """Gets the token_counter_output of this GenerativefirewallIndividualRulesConfig.  # noqa: E501


        :return: The token_counter_output of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :rtype: GenerativefirewallTokenCounterRuleConfig
        """
        return self._token_counter_output

    @token_counter_output.setter
    def token_counter_output(self, token_counter_output):
        """Sets the token_counter_output of this GenerativefirewallIndividualRulesConfig.


        :param token_counter_output: The token_counter_output of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :type: GenerativefirewallTokenCounterRuleConfig
        """

        self._token_counter_output = token_counter_output

    @property
    def unknown_external_source(self):
        """Gets the unknown_external_source of this GenerativefirewallIndividualRulesConfig.  # noqa: E501


        :return: The unknown_external_source of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :rtype: GenerativefirewallUnknownExternalSourceRuleConfig
        """
        return self._unknown_external_source

    @unknown_external_source.setter
    def unknown_external_source(self, unknown_external_source):
        """Sets the unknown_external_source of this GenerativefirewallIndividualRulesConfig.


        :param unknown_external_source: The unknown_external_source of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :type: GenerativefirewallUnknownExternalSourceRuleConfig
        """

        self._unknown_external_source = unknown_external_source

    @property
    def language_detection(self):
        """Gets the language_detection of this GenerativefirewallIndividualRulesConfig.  # noqa: E501


        :return: The language_detection of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :rtype: GenerativefirewallLanguageDetectionRuleConfig
        """
        return self._language_detection

    @language_detection.setter
    def language_detection(self, language_detection):
        """Sets the language_detection of this GenerativefirewallIndividualRulesConfig.


        :param language_detection: The language_detection of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :type: GenerativefirewallLanguageDetectionRuleConfig
        """

        self._language_detection = language_detection

    @property
    def prompt_injection(self):
        """Gets the prompt_injection of this GenerativefirewallIndividualRulesConfig.  # noqa: E501


        :return: The prompt_injection of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :rtype: GenerativefirewallPromptInjectionRuleConfig
        """
        return self._prompt_injection

    @prompt_injection.setter
    def prompt_injection(self, prompt_injection):
        """Sets the prompt_injection of this GenerativefirewallIndividualRulesConfig.


        :param prompt_injection: The prompt_injection of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :type: GenerativefirewallPromptInjectionRuleConfig
        """

        self._prompt_injection = prompt_injection

    @property
    def toxicity_rule_config_input(self):
        """Gets the toxicity_rule_config_input of this GenerativefirewallIndividualRulesConfig.  # noqa: E501


        :return: The toxicity_rule_config_input of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :rtype: GenerativefirewallToxicityRuleConfig
        """
        return self._toxicity_rule_config_input

    @toxicity_rule_config_input.setter
    def toxicity_rule_config_input(self, toxicity_rule_config_input):
        """Sets the toxicity_rule_config_input of this GenerativefirewallIndividualRulesConfig.


        :param toxicity_rule_config_input: The toxicity_rule_config_input of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :type: GenerativefirewallToxicityRuleConfig
        """

        self._toxicity_rule_config_input = toxicity_rule_config_input

    @property
    def toxicity_rule_config_output(self):
        """Gets the toxicity_rule_config_output of this GenerativefirewallIndividualRulesConfig.  # noqa: E501


        :return: The toxicity_rule_config_output of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :rtype: GenerativefirewallToxicityRuleConfig
        """
        return self._toxicity_rule_config_output

    @toxicity_rule_config_output.setter
    def toxicity_rule_config_output(self, toxicity_rule_config_output):
        """Sets the toxicity_rule_config_output of this GenerativefirewallIndividualRulesConfig.


        :param toxicity_rule_config_output: The toxicity_rule_config_output of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :type: GenerativefirewallToxicityRuleConfig
        """

        self._toxicity_rule_config_output = toxicity_rule_config_output

    @property
    def code_detection(self):
        """Gets the code_detection of this GenerativefirewallIndividualRulesConfig.  # noqa: E501


        :return: The code_detection of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :rtype: GenerativefirewallCodeDetectionRuleConfig
        """
        return self._code_detection

    @code_detection.setter
    def code_detection(self, code_detection):
        """Sets the code_detection of this GenerativefirewallIndividualRulesConfig.


        :param code_detection: The code_detection of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :type: GenerativefirewallCodeDetectionRuleConfig
        """

        self._code_detection = code_detection

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GenerativefirewallIndividualRulesConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GenerativefirewallIndividualRulesConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class FeatureflagsCustomerNameBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'signed_jwt_token_str': 'str'
    }

    attribute_map = {
        'signed_jwt_token_str': 'signedJwtTokenStr'
    }

    def __init__(self, signed_jwt_token_str=None):  # noqa: E501
        """FeatureflagsCustomerNameBody - a model defined in Swagger"""  # noqa: E501
        self._signed_jwt_token_str = None
        self.discriminator = None
        self.signed_jwt_token_str = signed_jwt_token_str

    @property
    def signed_jwt_token_str(self):
        """Gets the signed_jwt_token_str of this FeatureflagsCustomerNameBody.  # noqa: E501

        This is the signed JWT token (with RI private key that we don't share). We embed the public key in FeatureFlag server on startup. The jwt token str is decode with public key, and only updates DB on successful decoding (means it was encoded with right private key).  # noqa: E501

        :return: The signed_jwt_token_str of this FeatureflagsCustomerNameBody.  # noqa: E501
        :rtype: str
        """
        return self._signed_jwt_token_str

    @signed_jwt_token_str.setter
    def signed_jwt_token_str(self, signed_jwt_token_str):
        """Sets the signed_jwt_token_str of this FeatureflagsCustomerNameBody.

        This is the signed JWT token (with RI private key that we don't share). We embed the public key in FeatureFlag server on startup. The jwt token str is decode with public key, and only updates DB on successful decoding (means it was encoded with right private key).  # noqa: E501

        :param signed_jwt_token_str: The signed_jwt_token_str of this FeatureflagsCustomerNameBody.  # noqa: E501
        :type: str
        """
        if signed_jwt_token_str is None:
            raise ValueError("Invalid value for `signed_jwt_token_str`, must not be `None`")  # noqa: E501

        self._signed_jwt_token_str = signed_jwt_token_str

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FeatureflagsCustomerNameBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FeatureflagsCustomerNameBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class V1workspaceworkspaceWorkspaceIdUuidWorkspace(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'agent_ids': 'list[RimeUUID]',
        'default_agent_id': 'RimeUUID',
        'workspace_id': 'object',
        'description': 'str',
        'results_retention_in_days': 'int'
    }

    attribute_map = {
        'name': 'name',
        'agent_ids': 'agentIds',
        'default_agent_id': 'defaultAgentId',
        'workspace_id': 'workspaceId',
        'description': 'description',
        'results_retention_in_days': 'resultsRetentionInDays'
    }

    def __init__(self, name=None, agent_ids=None, default_agent_id=None, workspace_id=None, description=None, results_retention_in_days=None):  # noqa: E501
        """V1workspaceworkspaceWorkspaceIdUuidWorkspace - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._agent_ids = None
        self._default_agent_id = None
        self._workspace_id = None
        self._description = None
        self._results_retention_in_days = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if agent_ids is not None:
            self.agent_ids = agent_ids
        if default_agent_id is not None:
            self.default_agent_id = default_agent_id
        if workspace_id is not None:
            self.workspace_id = workspace_id
        if description is not None:
            self.description = description
        if results_retention_in_days is not None:
            self.results_retention_in_days = results_retention_in_days

    @property
    def name(self):
        """Gets the name of this V1workspaceworkspaceWorkspaceIdUuidWorkspace.  # noqa: E501

        Name of the Workspace.  # noqa: E501

        :return: The name of this V1workspaceworkspaceWorkspaceIdUuidWorkspace.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this V1workspaceworkspaceWorkspaceIdUuidWorkspace.

        Name of the Workspace.  # noqa: E501

        :param name: The name of this V1workspaceworkspaceWorkspaceIdUuidWorkspace.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def agent_ids(self):
        """Gets the agent_ids of this V1workspaceworkspaceWorkspaceIdUuidWorkspace.  # noqa: E501

        List of Agent IDs that can be used by the Workspace.  # noqa: E501

        :return: The agent_ids of this V1workspaceworkspaceWorkspaceIdUuidWorkspace.  # noqa: E501
        :rtype: list[RimeUUID]
        """
        return self._agent_ids

    @agent_ids.setter
    def agent_ids(self, agent_ids):
        """Sets the agent_ids of this V1workspaceworkspaceWorkspaceIdUuidWorkspace.

        List of Agent IDs that can be used by the Workspace.  # noqa: E501

        :param agent_ids: The agent_ids of this V1workspaceworkspaceWorkspaceIdUuidWorkspace.  # noqa: E501
        :type: list[RimeUUID]
        """

        self._agent_ids = agent_ids

    @property
    def default_agent_id(self):
        """Gets the default_agent_id of this V1workspaceworkspaceWorkspaceIdUuidWorkspace.  # noqa: E501


        :return: The default_agent_id of this V1workspaceworkspaceWorkspaceIdUuidWorkspace.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._default_agent_id

    @default_agent_id.setter
    def default_agent_id(self, default_agent_id):
        """Sets the default_agent_id of this V1workspaceworkspaceWorkspaceIdUuidWorkspace.


        :param default_agent_id: The default_agent_id of this V1workspaceworkspaceWorkspaceIdUuidWorkspace.  # noqa: E501
        :type: RimeUUID
        """

        self._default_agent_id = default_agent_id

    @property
    def workspace_id(self):
        """Gets the workspace_id of this V1workspaceworkspaceWorkspaceIdUuidWorkspace.  # noqa: E501

        Unique ID of an object in RIME.  # noqa: E501

        :return: The workspace_id of this V1workspaceworkspaceWorkspaceIdUuidWorkspace.  # noqa: E501
        :rtype: object
        """
        return self._workspace_id

    @workspace_id.setter
    def workspace_id(self, workspace_id):
        """Sets the workspace_id of this V1workspaceworkspaceWorkspaceIdUuidWorkspace.

        Unique ID of an object in RIME.  # noqa: E501

        :param workspace_id: The workspace_id of this V1workspaceworkspaceWorkspaceIdUuidWorkspace.  # noqa: E501
        :type: object
        """

        self._workspace_id = workspace_id

    @property
    def description(self):
        """Gets the description of this V1workspaceworkspaceWorkspaceIdUuidWorkspace.  # noqa: E501

        Description of the Workspace.  # noqa: E501

        :return: The description of this V1workspaceworkspaceWorkspaceIdUuidWorkspace.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this V1workspaceworkspaceWorkspaceIdUuidWorkspace.

        Description of the Workspace.  # noqa: E501

        :param description: The description of this V1workspaceworkspaceWorkspaceIdUuidWorkspace.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def results_retention_in_days(self):
        """Gets the results_retention_in_days of this V1workspaceworkspaceWorkspaceIdUuidWorkspace.  # noqa: E501


        :return: The results_retention_in_days of this V1workspaceworkspaceWorkspaceIdUuidWorkspace.  # noqa: E501
        :rtype: int
        """
        return self._results_retention_in_days

    @results_retention_in_days.setter
    def results_retention_in_days(self, results_retention_in_days):
        """Sets the results_retention_in_days of this V1workspaceworkspaceWorkspaceIdUuidWorkspace.


        :param results_retention_in_days: The results_retention_in_days of this V1workspaceworkspaceWorkspaceIdUuidWorkspace.  # noqa: E501
        :type: int
        """

        self._results_retention_in_days = results_retention_in_days

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1workspaceworkspaceWorkspaceIdUuidWorkspace, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1workspaceworkspaceWorkspaceIdUuidWorkspace):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa
"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import models into model package
from rime_sdk.swagger.swagger_client.models.agent_id_uuid_upgrade_body import AgentIdUuidUpgradeBody
from rime_sdk.swagger.swagger_client.models.agent_id_uuid_upgrade_body1 import AgentIdUuidUpgradeBody1
from rime_sdk.swagger.swagger_client.models.apigenerativefirewall_create_firewall_instance_request import ApigenerativefirewallCreateFirewallInstanceRequest
from rime_sdk.swagger.swagger_client.models.apigenerativefirewall_create_firewall_instance_response import ApigenerativefirewallCreateFirewallInstanceResponse
from rime_sdk.swagger.swagger_client.models.apigenerativefirewall_list_firewall_instances_response import ApigenerativefirewallListFirewallInstancesResponse
from rime_sdk.swagger.swagger_client.models.apigenerativefirewall_standard_info import ApigenerativefirewallStandardInfo
from rime_sdk.swagger.swagger_client.models.artifact_identifier_category_test_identifier import ArtifactIdentifierCategoryTestIdentifier
from rime_sdk.swagger.swagger_client.models.artifact_identifier_subset_test_metric_identifier import ArtifactIdentifierSubsetTestMetricIdentifier
from rime_sdk.swagger.swagger_client.models.artifact_identifier_test_case_metric_identifier import ArtifactIdentifierTestCaseMetricIdentifier
from rime_sdk.swagger.swagger_client.models.code_detection_details_code_substring import CodeDetectionDetailsCodeSubstring
from rime_sdk.swagger.swagger_client.models.config_generation_category_config_generation_service_response import ConfigGenerationCategoryConfigGenerationServiceResponse
from rime_sdk.swagger.swagger_client.models.config_generation_profiling_config_generation_service_response import ConfigGenerationProfilingConfigGenerationServiceResponse
from rime_sdk.swagger.swagger_client.models.config_generation_test_suite_config_generation_service_response import ConfigGenerationTestSuiteConfigGenerationServiceResponse
from rime_sdk.swagger.swagger_client.models.configvalidator_config_type_body import ConfigvalidatorConfigTypeBody
from rime_sdk.swagger.swagger_client.models.continuoustests_firewall_id_uuid_body import ContinuoustestsFirewallIdUuidBody
from rime_sdk.swagger.swagger_client.models.create_agent_request_aws_config import CreateAgentRequestAWSConfig
from rime_sdk.swagger.swagger_client.models.create_agent_request_azure_config import CreateAgentRequestAzureConfig
from rime_sdk.swagger.swagger_client.models.create_agent_request_gcp_config import CreateAgentRequestGCPConfig
from rime_sdk.swagger.swagger_client.models.create_agent_request_local_config import CreateAgentRequestLocalConfig
from rime_sdk.swagger.swagger_client.models.create_firewall_instance_request_is_the_request_for_create_firewall_instance import CreateFirewallInstanceRequestIsTheRequestForCreateFirewallInstance
from rime_sdk.swagger.swagger_client.models.create_firewall_request_scheduled_ct_parameters import CreateFirewallRequestScheduledCTParameters
from rime_sdk.swagger.swagger_client.models.crossplanetask_cross_plane_response import CrossplanetaskCrossPlaneResponse
from rime_sdk.swagger.swagger_client.models.custom_image_pull_secret import CustomImagePullSecret
from rime_sdk.swagger.swagger_client.models.custom_metric_custom_metric_metadata import CustomMetricCustomMetricMetadata
from rime_sdk.swagger.swagger_client.models.customermanagedkey_customer_managed_key_config import CustomermanagedkeyCustomerManagedKeyConfig
from rime_sdk.swagger.swagger_client.models.customermanagedkey_key_provider import CustomermanagedkeyKeyProvider
from rime_sdk.swagger.swagger_client.models.customermanagedkey_key_status import CustomermanagedkeyKeyStatus
from rime_sdk.swagger.swagger_client.models.custommonitors_name_body import CustommonitorsNameBody
from rime_sdk.swagger.swagger_client.models.data_data_stream_id_uuid_body import DataDataStreamIdUuidBody
from rime_sdk.swagger.swagger_client.models.data_params_feature_intersection import DataParamsFeatureIntersection
from rime_sdk.swagger.swagger_client.models.data_params_ranking_info import DataParamsRankingInfo
from rime_sdk.swagger.swagger_client.models.data_profiling_column_type_info import DataProfilingColumnTypeInfo
from rime_sdk.swagger.swagger_client.models.data_profiling_feature_relationship_info import DataProfilingFeatureRelationshipInfo
from rime_sdk.swagger.swagger_client.models.datacollector_datapoint import DatacollectorDatapoint
from rime_sdk.swagger.swagger_client.models.datacollector_datapoint_row import DatacollectorDatapointRow
from rime_sdk.swagger.swagger_client.models.dataset_ct_dataset_type import DatasetCTDatasetType
from rime_sdk.swagger.swagger_client.models.dataset_ct_info import DatasetCTInfo
from rime_sdk.swagger.swagger_client.models.dataset_dataset import DatasetDataset
from rime_sdk.swagger.swagger_client.models.dataset_id_prediction_body import DatasetIdPredictionBody
from rime_sdk.swagger.swagger_client.models.datastream_project_id_uuid_body import DatastreamProjectIdUuidBody
from rime_sdk.swagger.swagger_client.models.detection_detection_event import DetectionDetectionEvent
from rime_sdk.swagger.swagger_client.models.detection_event_detail import DetectionEventDetail
from rime_sdk.swagger.swagger_client.models.detection_event_type import DetectionEventType
from rime_sdk.swagger.swagger_client.models.detection_metric_degradation_event_details import DetectionMetricDegradationEventDetails
from rime_sdk.swagger.swagger_client.models.detection_resolution import DetectionResolution
from rime_sdk.swagger.swagger_client.models.detection_security_event_details import DetectionSecurityEventDetails
from rime_sdk.swagger.swagger_client.models.difference_from_target_difference import DifferenceFromTargetDifference
from rime_sdk.swagger.swagger_client.models.difference_from_target_target import DifferenceFromTargetTarget
from rime_sdk.swagger.swagger_client.models.digest_config_digest_frequency import DigestConfigDigestFrequency
from rime_sdk.swagger.swagger_client.models.featureflags_customer_name_body import FeatureflagsCustomerNameBody
from rime_sdk.swagger.swagger_client.models.file_security_report_dependency import FileSecurityReportDependency
from rime_sdk.swagger.swagger_client.models.filescanning_package_url import FilescanningPackageURL
from rime_sdk.swagger.swagger_client.models.fileserver_check_object_exists_response import FileserverCheckObjectExistsResponse
from rime_sdk.swagger.swagger_client.models.fileserver_delete_object_response import FileserverDeleteObjectResponse
from rime_sdk.swagger.swagger_client.models.fileserver_get_read_object_presigned_link_response import FileserverGetReadObjectPresignedLinkResponse
from rime_sdk.swagger.swagger_client.models.fileserver_get_upload_object_presigned_link_response import FileserverGetUploadObjectPresignedLinkResponse
from rime_sdk.swagger.swagger_client.models.fileserver_list_objects_response import FileserverListObjectsResponse
from rime_sdk.swagger.swagger_client.models.firewall_firewall import FirewallFirewall
from rime_sdk.swagger.swagger_client.models.firewall_firewall_firewall_id_uuid_body import FirewallFirewallFirewallIdUuidBody
from rime_sdk.swagger.swagger_client.models.firewall_instance_id_uuid_heartbeat_body import FirewallInstanceIdUuidHeartbeatBody
from rime_sdk.swagger.swagger_client.models.firewall_instance_id_uuid_validate_body import FirewallInstanceIdUuidValidateBody
from rime_sdk.swagger.swagger_client.models.firewall_latest_run_info import FirewallLatestRunInfo
from rime_sdk.swagger.swagger_client.models.firewall_scheduled_ct_info import FirewallScheduledCTInfo
from rime_sdk.swagger.swagger_client.models.firewall_test_category_severity import FirewallTestCategorySeverity
from rime_sdk.swagger.swagger_client.models.firewallinstance_firewall_instance_firewall_instance_id_uuid_body import FirewallinstanceFirewallInstanceFirewallInstanceIdUuidBody
from rime_sdk.swagger.swagger_client.models.flagged_substring_request_body_component import FlaggedSubstringRequestBodyComponent
from rime_sdk.swagger.swagger_client.models.generative_testing_result_example import GenerativeTestingResultExample
from rime_sdk.swagger.swagger_client.models.generativefirewall_code_detection_details import GenerativefirewallCodeDetectionDetails
from rime_sdk.swagger.swagger_client.models.generativefirewall_code_detection_rule_config import GenerativefirewallCodeDetectionRuleConfig
from rime_sdk.swagger.swagger_client.models.generativefirewall_custom_pii_entity import GenerativefirewallCustomPiiEntity
from rime_sdk.swagger.swagger_client.models.generativefirewall_firewall_action import GenerativefirewallFirewallAction
from rime_sdk.swagger.swagger_client.models.generativefirewall_firewall_instance_deployment_config import GenerativefirewallFirewallInstanceDeploymentConfig
from rime_sdk.swagger.swagger_client.models.generativefirewall_firewall_instance_info import GenerativefirewallFirewallInstanceInfo
from rime_sdk.swagger.swagger_client.models.generativefirewall_firewall_instance_status import GenerativefirewallFirewallInstanceStatus
from rime_sdk.swagger.swagger_client.models.generativefirewall_firewall_rule_config import GenerativefirewallFirewallRuleConfig
from rime_sdk.swagger.swagger_client.models.generativefirewall_firewall_rule_type import GenerativefirewallFirewallRuleType
from rime_sdk.swagger.swagger_client.models.generativefirewall_firewall_tokenizer import GenerativefirewallFirewallTokenizer
from rime_sdk.swagger.swagger_client.models.generativefirewall_flagged_substring import GenerativefirewallFlaggedSubstring
from rime_sdk.swagger.swagger_client.models.generativefirewall_get_firewall_effective_config_response import GenerativefirewallGetFirewallEffectiveConfigResponse
from rime_sdk.swagger.swagger_client.models.generativefirewall_get_firewall_instance_response import GenerativefirewallGetFirewallInstanceResponse
from rime_sdk.swagger.swagger_client.models.generativefirewall_individual_rules_config import GenerativefirewallIndividualRulesConfig
from rime_sdk.swagger.swagger_client.models.generativefirewall_language_detection_details import GenerativefirewallLanguageDetectionDetails
from rime_sdk.swagger.swagger_client.models.generativefirewall_language_detection_rule_config import GenerativefirewallLanguageDetectionRuleConfig
from rime_sdk.swagger.swagger_client.models.generativefirewall_off_topic_rule_config import GenerativefirewallOffTopicRuleConfig
from rime_sdk.swagger.swagger_client.models.generativefirewall_pii_detection_details import GenerativefirewallPiiDetectionDetails
from rime_sdk.swagger.swagger_client.models.generativefirewall_pii_detection_rule_config import GenerativefirewallPiiDetectionRuleConfig
from rime_sdk.swagger.swagger_client.models.generativefirewall_pii_entity_type import GenerativefirewallPiiEntityType
from rime_sdk.swagger.swagger_client.models.generativefirewall_prompt_injection_details import GenerativefirewallPromptInjectionDetails
from rime_sdk.swagger.swagger_client.models.generativefirewall_prompt_injection_rule_config import GenerativefirewallPromptInjectionRuleConfig
from rime_sdk.swagger.swagger_client.models.generativefirewall_raw_model_prediction import GenerativefirewallRawModelPrediction
from rime_sdk.swagger.swagger_client.models.generativefirewall_rule_output import GenerativefirewallRuleOutput
from rime_sdk.swagger.swagger_client.models.generativefirewall_rule_sensitivity import GenerativefirewallRuleSensitivity
from rime_sdk.swagger.swagger_client.models.generativefirewall_token_counter_rule_config import GenerativefirewallTokenCounterRuleConfig
from rime_sdk.swagger.swagger_client.models.generativefirewall_toxicity_detection_details import GenerativefirewallToxicityDetectionDetails
from rime_sdk.swagger.swagger_client.models.generativefirewall_toxicity_rule_config import GenerativefirewallToxicityRuleConfig
from rime_sdk.swagger.swagger_client.models.generativefirewall_unknown_external_source_rule_config import GenerativefirewallUnknownExternalSourceRuleConfig
from rime_sdk.swagger.swagger_client.models.generativefirewall_update_firewall_instance_response import GenerativefirewallUpdateFirewallInstanceResponse
from rime_sdk.swagger.swagger_client.models.generativefirewall_validate_response import GenerativefirewallValidateResponse
from rime_sdk.swagger.swagger_client.models.generativetesting_generative_testing_result import GenerativetestingGenerativeTestingResult
from rime_sdk.swagger.swagger_client.models.generativetesting_generative_testing_result_standard_info import GenerativetestingGenerativeTestingResultStandardInfo
from rime_sdk.swagger.swagger_client.models.generativetesting_get_generative_model_test_results_request_query import GenerativetestingGetGenerativeModelTestResultsRequestQuery
from rime_sdk.swagger.swagger_client.models.generativetesting_get_generative_model_test_results_response import GenerativetestingGetGenerativeModelTestResultsResponse
from rime_sdk.swagger.swagger_client.models.generativetesting_objective_sub_category import GenerativetestingObjectiveSubCategory
from rime_sdk.swagger.swagger_client.models.generativetesting_start_generative_model_test_request import GenerativetestingStartGenerativeModelTestRequest
from rime_sdk.swagger.swagger_client.models.generativetesting_start_generative_model_test_response import GenerativetestingStartGenerativeModelTestResponse
from rime_sdk.swagger.swagger_client.models.generativetesting_threat import GenerativetestingThreat
from rime_sdk.swagger.swagger_client.models.googlerpc_status import GooglerpcStatus
from rime_sdk.swagger.swagger_client.models.heartbeat_agent_id_uuid_body import HeartbeatAgentIdUuidBody
from rime_sdk.swagger.swagger_client.models.image_reference_reference_type import ImageReferenceReferenceType
from rime_sdk.swagger.swagger_client.models.integration_integration_level import IntegrationIntegrationLevel
from rime_sdk.swagger.swagger_client.models.integration_integration_schema import IntegrationIntegrationSchema
from rime_sdk.swagger.swagger_client.models.integration_integration_type import IntegrationIntegrationType
from rime_sdk.swagger.swagger_client.models.integration_variable_sensitivity import IntegrationVariableSensitivity
from rime_sdk.swagger.swagger_client.models.integrations_integration_id_uuid_body import IntegrationsIntegrationIdUuidBody
from rime_sdk.swagger.swagger_client.models.job_data_continuous_incremental_test import JobDataContinuousIncrementalTest
from rime_sdk.swagger.swagger_client.models.job_data_scan import JobDataScan
from rime_sdk.swagger.swagger_client.models.job_data_stress_test import JobDataStressTest
from rime_sdk.swagger.swagger_client.models.language_detection_details_language_substring import LanguageDetectionDetailsLanguageSubstring
from rime_sdk.swagger.swagger_client.models.libgenerative_severity import LibgenerativeSeverity
from rime_sdk.swagger.swagger_client.models.list_api_tokens_request_list_api_tokens_query import ListAPITokensRequestListAPITokensQuery
from rime_sdk.swagger.swagger_client.models.list_agents_request_list_agents_query import ListAgentsRequestListAgentsQuery
from rime_sdk.swagger.swagger_client.models.list_datasets_request_datasets_query import ListDatasetsRequestDatasetsQuery
from rime_sdk.swagger.swagger_client.models.list_file_scan_results_request_file_scan_query import ListFileScanResultsRequestFileScanQuery
from rime_sdk.swagger.swagger_client.models.list_firewall_instances_request_list_firewall_instances_query import ListFirewallInstancesRequestListFirewallInstancesQuery
from rime_sdk.swagger.swagger_client.models.list_images_request_pip_library_filter import ListImagesRequestPipLibraryFilter
from rime_sdk.swagger.swagger_client.models.list_metric_identifiers_response_aggregated_metric import ListMetricIdentifiersResponseAggregatedMetric
from rime_sdk.swagger.swagger_client.models.list_metric_identifiers_response_feature_metric_without_subsets import ListMetricIdentifiersResponseFeatureMetricWithoutSubsets
from rime_sdk.swagger.swagger_client.models.list_metric_identifiers_response_feature_metrics import ListMetricIdentifiersResponseFeatureMetrics
from rime_sdk.swagger.swagger_client.models.list_metric_identifiers_response_subset_metric import ListMetricIdentifiersResponseSubsetMetric
from rime_sdk.swagger.swagger_client.models.list_metric_identifiers_response_subset_metrics import ListMetricIdentifiersResponseSubsetMetrics
from rime_sdk.swagger.swagger_client.models.list_models_request_model_query import ListModelsRequestModelQuery
from rime_sdk.swagger.swagger_client.models.list_monitors_request_filter import ListMonitorsRequestFilter
from rime_sdk.swagger.swagger_client.models.list_notifications_request_list_notifications_query import ListNotificationsRequestListNotificationsQuery
from rime_sdk.swagger.swagger_client.models.list_prediction_sets_request_prediction_query import ListPredictionSetsRequestPredictionQuery
from rime_sdk.swagger.swagger_client.models.list_summary_tests_request_list_summary_tests_query import ListSummaryTestsRequestListSummaryTestsQuery
from rime_sdk.swagger.swagger_client.models.list_test_cases_request_list_test_cases_query import ListTestCasesRequestListTestCasesQuery
from rime_sdk.swagger.swagger_client.models.managed_image_package_requirement import ManagedImagePackageRequirement
from rime_sdk.swagger.swagger_client.models.managed_image_pip_library import ManagedImagePipLibrary
from rime_sdk.swagger.swagger_client.models.managed_image_pip_requirement import ManagedImagePipRequirement
from rime_sdk.swagger.swagger_client.models.managed_image_role_type import ManagedImageRoleType
from rime_sdk.swagger.swagger_client.models.model_model import ModelModel
from rime_sdk.swagger.swagger_client.models.modelcards_model_card_model_card_id_uuid_body import ModelcardsModelCardModelCardIdUuidBody
from rime_sdk.swagger.swagger_client.models.monitor_aggregation import MonitorAggregation
from rime_sdk.swagger.swagger_client.models.monitor_aggregation_type import MonitorAggregationType
from rime_sdk.swagger.swagger_client.models.monitor_anomaly_config import MonitorAnomalyConfig
from rime_sdk.swagger.swagger_client.models.monitor_artifact_identifier import MonitorArtifactIdentifier
from rime_sdk.swagger.swagger_client.models.monitor_difference_from_target import MonitorDifferenceFromTarget
from rime_sdk.swagger.swagger_client.models.monitor_excluded_transforms import MonitorExcludedTransforms
from rime_sdk.swagger.swagger_client.models.monitor_metric_degradation_config import MonitorMetricDegradationConfig
from rime_sdk.swagger.swagger_client.models.monitor_monitor import MonitorMonitor
from rime_sdk.swagger.swagger_client.models.monitor_monitor_type import MonitorMonitorType
from rime_sdk.swagger.swagger_client.models.monitor_threshold import MonitorThreshold
from rime_sdk.swagger.swagger_client.models.monitor_threshold_type import MonitorThresholdType
from rime_sdk.swagger.swagger_client.models.monitor_transform import MonitorTransform
from rime_sdk.swagger.swagger_client.models.monitoring_config_alert_level import MonitoringConfigAlertLevel
from rime_sdk.swagger.swagger_client.models.monitors_monitor_id_uuid_body import MonitorsMonitorIdUuidBody
from rime_sdk.swagger.swagger_client.models.notification_digest_config import NotificationDigestConfig
from rime_sdk.swagger.swagger_client.models.notification_job_action_config import NotificationJobActionConfig
from rime_sdk.swagger.swagger_client.models.notification_monitoring_config import NotificationMonitoringConfig
from rime_sdk.swagger.swagger_client.models.notification_notification import NotificationNotification
from rime_sdk.swagger.swagger_client.models.notification_notification_type import NotificationNotificationType
from rime_sdk.swagger.swagger_client.models.notification_object_type import NotificationObjectType
from rime_sdk.swagger.swagger_client.models.notification_webhook_config import NotificationWebhookConfig
from rime_sdk.swagger.swagger_client.models.notifsettings_notification_id_uuid_body import NotifsettingsNotificationIdUuidBody
from rime_sdk.swagger.swagger_client.models.pii_detection_details_flagged_entity import PiiDetectionDetailsFlaggedEntity
from rime_sdk.swagger.swagger_client.models.predictions_model_id_uuid_body import PredictionsModelIdUuidBody
from rime_sdk.swagger.swagger_client.models.project_activate_schedule_for_project_response import ProjectActivateScheduleForProjectResponse
from rime_sdk.swagger.swagger_client.models.project_add_users_to_project_response import ProjectAddUsersToProjectResponse
from rime_sdk.swagger.swagger_client.models.project_create_project_request import ProjectCreateProjectRequest
from rime_sdk.swagger.swagger_client.models.project_create_project_response import ProjectCreateProjectResponse
from rime_sdk.swagger.swagger_client.models.project_deactivate_schedule_for_project_response import ProjectDeactivateScheduleForProjectResponse
from rime_sdk.swagger.swagger_client.models.project_delete_project_response import ProjectDeleteProjectResponse
from rime_sdk.swagger.swagger_client.models.project_get_project_response import ProjectGetProjectResponse
from rime_sdk.swagger.swagger_client.models.project_get_project_url_response import ProjectGetProjectURLResponse
from rime_sdk.swagger.swagger_client.models.project_get_workspace_roles_for_project_response import ProjectGetWorkspaceRolesForProjectResponse
from rime_sdk.swagger.swagger_client.models.project_id_uuid_dataset_body import ProjectIdUuidDatasetBody
from rime_sdk.swagger.swagger_client.models.project_id_uuid_model_body import ProjectIdUuidModelBody
from rime_sdk.swagger.swagger_client.models.project_list_projects_request_query import ProjectListProjectsRequestQuery
from rime_sdk.swagger.swagger_client.models.project_list_projects_response import ProjectListProjectsResponse
from rime_sdk.swagger.swagger_client.models.project_list_users_of_project_response import ProjectListUsersOfProjectResponse
from rime_sdk.swagger.swagger_client.models.project_owner_details import ProjectOwnerDetails
from rime_sdk.swagger.swagger_client.models.project_project import ProjectProject
from rime_sdk.swagger.swagger_client.models.project_project_status import ProjectProjectStatus
from rime_sdk.swagger.swagger_client.models.project_project_with_details import ProjectProjectWithDetails
from rime_sdk.swagger.swagger_client.models.project_remove_user_from_project_response import ProjectRemoveUserFromProjectResponse
from rime_sdk.swagger.swagger_client.models.project_schedule_info import ProjectScheduleInfo
from rime_sdk.swagger.swagger_client.models.project_update_project_response import ProjectUpdateProjectResponse
from rime_sdk.swagger.swagger_client.models.project_update_user_of_project_response import ProjectUpdateUserOfProjectResponse
from rime_sdk.swagger.swagger_client.models.project_update_workspace_roles_for_project_response import ProjectUpdateWorkspaceRolesForProjectResponse
from rime_sdk.swagger.swagger_client.models.projects_project_id_uuid_body import ProjectsProjectIdUuidBody
from rime_sdk.swagger.swagger_client.models.protobuf_any import ProtobufAny
from rime_sdk.swagger.swagger_client.models.protobuf_null_value import ProtobufNullValue
from rime_sdk.swagger.swagger_client.models.raw_model_prediction_text_classification_pred import RawModelPredictionTextClassificationPred
from rime_sdk.swagger.swagger_client.models.registry_connection_info import RegistryConnectionInfo
from rime_sdk.swagger.swagger_client.models.registry_data_collector_info import RegistryDataCollectorInfo
from rime_sdk.swagger.swagger_client.models.registry_data_file_info import RegistryDataFileInfo
from rime_sdk.swagger.swagger_client.models.registry_data_info import RegistryDataInfo
from rime_sdk.swagger.swagger_client.models.registry_data_loading_info import RegistryDataLoadingInfo
from rime_sdk.swagger.swagger_client.models.registry_data_params import RegistryDataParams
from rime_sdk.swagger.swagger_client.models.registry_data_type import RegistryDataType
from rime_sdk.swagger.swagger_client.models.registry_databricks_info import RegistryDatabricksInfo
from rime_sdk.swagger.swagger_client.models.registry_generative_language_model_info import RegistryGenerativeLanguageModelInfo
from rime_sdk.swagger.swagger_client.models.registry_hugging_face_data_info import RegistryHuggingFaceDataInfo
from rime_sdk.swagger.swagger_client.models.registry_hugging_face_model_info import RegistryHuggingFaceModelInfo
from rime_sdk.swagger.swagger_client.models.registry_metadata import RegistryMetadata
from rime_sdk.swagger.swagger_client.models.registry_model_path_info import RegistryModelPathInfo
from rime_sdk.swagger.swagger_client.models.registry_open_ai_chat_completion_model_info import RegistryOpenAIChatCompletionModelInfo
from rime_sdk.swagger.swagger_client.models.registry_pred_info import RegistryPredInfo
from rime_sdk.swagger.swagger_client.models.registry_prediction_params import RegistryPredictionParams
from rime_sdk.swagger.swagger_client.models.registry_validity_status import RegistryValidityStatus
from rime_sdk.swagger.swagger_client.models.registryprediction_prediction import RegistrypredictionPrediction
from rime_sdk.swagger.swagger_client.models.rename_test_run_id_body import RenameTestRunIdBody
from rime_sdk.swagger.swagger_client.models.resetpassword_user_id_uuid_body import ResetpasswordUserIdUuidBody
from rime_sdk.swagger.swagger_client.models.rime_api_token_info import RimeAPITokenInfo
from rime_sdk.swagger.swagger_client.models.rime_actor_role import RimeActorRole
from rime_sdk.swagger.swagger_client.models.rime_add_users_to_workspace_response import RimeAddUsersToWorkspaceResponse
from rime_sdk.swagger.swagger_client.models.rime_agent import RimeAgent
from rime_sdk.swagger.swagger_client.models.rime_agent_desired_state import RimeAgentDesiredState
from rime_sdk.swagger.swagger_client.models.rime_agent_status import RimeAgentStatus
from rime_sdk.swagger.swagger_client.models.rime_agent_type import RimeAgentType
from rime_sdk.swagger.swagger_client.models.rime_attack_objective import RimeAttackObjective
from rime_sdk.swagger.swagger_client.models.rime_attack_technique import RimeAttackTechnique
from rime_sdk.swagger.swagger_client.models.rime_cancel_job_response import RimeCancelJobResponse
from rime_sdk.swagger.swagger_client.models.rime_category_metric import RimeCategoryMetric
from rime_sdk.swagger.swagger_client.models.rime_category_test_result import RimeCategoryTestResult
from rime_sdk.swagger.swagger_client.models.rime_config_type import RimeConfigType
from rime_sdk.swagger.swagger_client.models.rime_configure_integration_request_integration_variable import RimeConfigureIntegrationRequestIntegrationVariable
from rime_sdk.swagger.swagger_client.models.rime_configure_integration_response import RimeConfigureIntegrationResponse
from rime_sdk.swagger.swagger_client.models.rime_continuous_test_job_progress import RimeContinuousTestJobProgress
from rime_sdk.swagger.swagger_client.models.rime_continuous_test_run_progress import RimeContinuousTestRunProgress
from rime_sdk.swagger.swagger_client.models.rime_create_api_token_request import RimeCreateAPITokenRequest
from rime_sdk.swagger.swagger_client.models.rime_create_api_token_response import RimeCreateAPITokenResponse
from rime_sdk.swagger.swagger_client.models.rime_create_agent_request import RimeCreateAgentRequest
from rime_sdk.swagger.swagger_client.models.rime_create_agent_response import RimeCreateAgentResponse
from rime_sdk.swagger.swagger_client.models.rime_create_custom_monitor_response import RimeCreateCustomMonitorResponse
from rime_sdk.swagger.swagger_client.models.rime_create_customer_managed_key_request import RimeCreateCustomerManagedKeyRequest
from rime_sdk.swagger.swagger_client.models.rime_create_customer_managed_key_response import RimeCreateCustomerManagedKeyResponse
from rime_sdk.swagger.swagger_client.models.rime_create_firewall_agent_request import RimeCreateFirewallAgentRequest
from rime_sdk.swagger.swagger_client.models.rime_create_firewall_agent_response import RimeCreateFirewallAgentResponse
from rime_sdk.swagger.swagger_client.models.rime_create_firewall_instance_response import RimeCreateFirewallInstanceResponse
from rime_sdk.swagger.swagger_client.models.rime_create_firewall_request import RimeCreateFirewallRequest
from rime_sdk.swagger.swagger_client.models.rime_create_firewall_response import RimeCreateFirewallResponse
from rime_sdk.swagger.swagger_client.models.rime_create_image_request import RimeCreateImageRequest
from rime_sdk.swagger.swagger_client.models.rime_create_image_response import RimeCreateImageResponse
from rime_sdk.swagger.swagger_client.models.rime_create_integration_request import RimeCreateIntegrationRequest
from rime_sdk.swagger.swagger_client.models.rime_create_integration_response import RimeCreateIntegrationResponse
from rime_sdk.swagger.swagger_client.models.rime_create_model_card_request import RimeCreateModelCardRequest
from rime_sdk.swagger.swagger_client.models.rime_create_model_card_response import RimeCreateModelCardResponse
from rime_sdk.swagger.swagger_client.models.rime_create_notification_request import RimeCreateNotificationRequest
from rime_sdk.swagger.swagger_client.models.rime_create_notification_response import RimeCreateNotificationResponse
from rime_sdk.swagger.swagger_client.models.rime_create_schedule_request import RimeCreateScheduleRequest
from rime_sdk.swagger.swagger_client.models.rime_create_schedule_response import RimeCreateScheduleResponse
from rime_sdk.swagger.swagger_client.models.rime_create_user_request import RimeCreateUserRequest
from rime_sdk.swagger.swagger_client.models.rime_create_user_response import RimeCreateUserResponse
from rime_sdk.swagger.swagger_client.models.rime_create_workspace_request import RimeCreateWorkspaceRequest
from rime_sdk.swagger.swagger_client.models.rime_create_workspace_response import RimeCreateWorkspaceResponse
from rime_sdk.swagger.swagger_client.models.rime_delete_agent_response import RimeDeleteAgentResponse
from rime_sdk.swagger.swagger_client.models.rime_delete_custom_monitor_response import RimeDeleteCustomMonitorResponse
from rime_sdk.swagger.swagger_client.models.rime_delete_dataset_response import RimeDeleteDatasetResponse
from rime_sdk.swagger.swagger_client.models.rime_delete_firewall_instance_response import RimeDeleteFirewallInstanceResponse
from rime_sdk.swagger.swagger_client.models.rime_delete_firewall_response import RimeDeleteFirewallResponse
from rime_sdk.swagger.swagger_client.models.rime_delete_image_response import RimeDeleteImageResponse
from rime_sdk.swagger.swagger_client.models.rime_delete_integration_response import RimeDeleteIntegrationResponse
from rime_sdk.swagger.swagger_client.models.rime_delete_model_card_response import RimeDeleteModelCardResponse
from rime_sdk.swagger.swagger_client.models.rime_delete_model_response import RimeDeleteModelResponse
from rime_sdk.swagger.swagger_client.models.rime_delete_prediction_set_response import RimeDeletePredictionSetResponse
from rime_sdk.swagger.swagger_client.models.rime_delete_schedule_response import RimeDeleteScheduleResponse
from rime_sdk.swagger.swagger_client.models.rime_delete_uploaded_file_url_response import RimeDeleteUploadedFileURLResponse
from rime_sdk.swagger.swagger_client.models.rime_detailed_upgrade_status import RimeDetailedUpgradeStatus
from rime_sdk.swagger.swagger_client.models.rime_ensure_image_existence_response import RimeEnsureImageExistenceResponse
from rime_sdk.swagger.swagger_client.models.rime_failing_row import RimeFailingRow
from rime_sdk.swagger.swagger_client.models.rime_failing_rows_result import RimeFailingRowsResult
from rime_sdk.swagger.swagger_client.models.rime_feature_flags import RimeFeatureFlags
from rime_sdk.swagger.swagger_client.models.rime_feature_type import RimeFeatureType
from rime_sdk.swagger.swagger_client.models.rime_file_scan_result import RimeFileScanResult
from rime_sdk.swagger.swagger_client.models.rime_file_security_report import RimeFileSecurityReport
from rime_sdk.swagger.swagger_client.models.rime_firewall_instance_heartbeat_response import RimeFirewallInstanceHeartbeatResponse
from rime_sdk.swagger.swagger_client.models.rime_float_list import RimeFloatList
from rime_sdk.swagger.swagger_client.models.rime_generative_model_test_progress import RimeGenerativeModelTestProgress
from rime_sdk.swagger.swagger_client.models.rime_get_agent_response import RimeGetAgentResponse
from rime_sdk.swagger.swagger_client.models.rime_get_customer_managed_key_response import RimeGetCustomerManagedKeyResponse
from rime_sdk.swagger.swagger_client.models.rime_get_datapoints_response import RimeGetDatapointsResponse
from rime_sdk.swagger.swagger_client.models.rime_get_dataset_file_upload_url_request import RimeGetDatasetFileUploadURLRequest
from rime_sdk.swagger.swagger_client.models.rime_get_dataset_file_upload_url_response import RimeGetDatasetFileUploadURLResponse
from rime_sdk.swagger.swagger_client.models.rime_get_dataset_response import RimeGetDatasetResponse
from rime_sdk.swagger.swagger_client.models.rime_get_enabled_feature_response import RimeGetEnabledFeatureResponse
from rime_sdk.swagger.swagger_client.models.rime_get_feature_flag_jwt_response import RimeGetFeatureFlagJwtResponse
from rime_sdk.swagger.swagger_client.models.rime_get_feature_flags_response import RimeGetFeatureFlagsResponse
from rime_sdk.swagger.swagger_client.models.rime_get_file_scan_result_response import RimeGetFileScanResultResponse
from rime_sdk.swagger.swagger_client.models.rime_get_firewall_response import RimeGetFirewallResponse
from rime_sdk.swagger.swagger_client.models.rime_get_image_response import RimeGetImageResponse
from rime_sdk.swagger.swagger_client.models.rime_get_integration_response import RimeGetIntegrationResponse
from rime_sdk.swagger.swagger_client.models.rime_get_job_response import RimeGetJobResponse
from rime_sdk.swagger.swagger_client.models.rime_get_key_status_response import RimeGetKeyStatusResponse
from rime_sdk.swagger.swagger_client.models.rime_get_latest_logs_response import RimeGetLatestLogsResponse
from rime_sdk.swagger.swagger_client.models.rime_get_limit_status_response import RimeGetLimitStatusResponse
from rime_sdk.swagger.swagger_client.models.rime_get_model_card_response import RimeGetModelCardResponse
from rime_sdk.swagger.swagger_client.models.rime_get_model_directory_upload_urls_request import RimeGetModelDirectoryUploadURLsRequest
from rime_sdk.swagger.swagger_client.models.rime_get_model_directory_upload_urls_response import RimeGetModelDirectoryUploadURLsResponse
from rime_sdk.swagger.swagger_client.models.rime_get_model_response import RimeGetModelResponse
from rime_sdk.swagger.swagger_client.models.rime_get_model_security_report_response import RimeGetModelSecurityReportResponse
from rime_sdk.swagger.swagger_client.models.rime_get_monitor_result_response import RimeGetMonitorResultResponse
from rime_sdk.swagger.swagger_client.models.rime_get_prediction_set_response import RimeGetPredictionSetResponse
from rime_sdk.swagger.swagger_client.models.rime_get_predictions_response import RimeGetPredictionsResponse
from rime_sdk.swagger.swagger_client.models.rime_get_project_id_response import RimeGetProjectIDResponse
from rime_sdk.swagger.swagger_client.models.rime_get_rime_info_response import RimeGetRIMEInfoResponse
from rime_sdk.swagger.swagger_client.models.rime_get_schedule_response import RimeGetScheduleResponse
from rime_sdk.swagger.swagger_client.models.rime_get_test_run_id_response import RimeGetTestRunIDResponse
from rime_sdk.swagger.swagger_client.models.rime_get_time_series_response import RimeGetTimeSeriesResponse
from rime_sdk.swagger.swagger_client.models.rime_get_url_response import RimeGetURLResponse
from rime_sdk.swagger.swagger_client.models.rime_get_upgrade_for_agent_response import RimeGetUpgradeForAgentResponse
from rime_sdk.swagger.swagger_client.models.rime_get_user_response import RimeGetUserResponse
from rime_sdk.swagger.swagger_client.models.rime_get_validate_dataset_task_status_response import RimeGetValidateDatasetTaskStatusResponse
from rime_sdk.swagger.swagger_client.models.rime_get_validate_model_task_status_response import RimeGetValidateModelTaskStatusResponse
from rime_sdk.swagger.swagger_client.models.rime_get_validate_predictions_task_status_response import RimeGetValidatePredictionsTaskStatusResponse
from rime_sdk.swagger.swagger_client.models.rime_get_workspace_response import RimeGetWorkspaceResponse
from rime_sdk.swagger.swagger_client.models.rime_heartbeat_response import RimeHeartbeatResponse
from rime_sdk.swagger.swagger_client.models.rime_image_reference import RimeImageReference
from rime_sdk.swagger.swagger_client.models.rime_int_list import RimeIntList
from rime_sdk.swagger.swagger_client.models.rime_integration_info import RimeIntegrationInfo
from rime_sdk.swagger.swagger_client.models.rime_job_data import RimeJobData
from rime_sdk.swagger.swagger_client.models.rime_job_data_generative_model_test import RimeJobDataGenerativeModelTest
from rime_sdk.swagger.swagger_client.models.rime_job_metadata import RimeJobMetadata
from rime_sdk.swagger.swagger_client.models.rime_job_type import RimeJobType
from rime_sdk.swagger.swagger_client.models.rime_job_view import RimeJobView
from rime_sdk.swagger.swagger_client.models.rime_language import RimeLanguage
from rime_sdk.swagger.swagger_client.models.rime_license_feature import RimeLicenseFeature
from rime_sdk.swagger.swagger_client.models.rime_license_limit import RimeLicenseLimit
from rime_sdk.swagger.swagger_client.models.rime_limit_status import RimeLimitStatus
from rime_sdk.swagger.swagger_client.models.rime_limit_status_status import RimeLimitStatusStatus
from rime_sdk.swagger.swagger_client.models.rime_list_api_tokens_response import RimeListAPITokensResponse
from rime_sdk.swagger.swagger_client.models.rime_list_agents_response import RimeListAgentsResponse
from rime_sdk.swagger.swagger_client.models.rime_list_current_user_roles_response import RimeListCurrentUserRolesResponse
from rime_sdk.swagger.swagger_client.models.rime_list_datasets_response import RimeListDatasetsResponse
from rime_sdk.swagger.swagger_client.models.rime_list_detection_events_request_query import RimeListDetectionEventsRequestQuery
from rime_sdk.swagger.swagger_client.models.rime_list_detection_events_response import RimeListDetectionEventsResponse
from rime_sdk.swagger.swagger_client.models.rime_list_enabled_features_response import RimeListEnabledFeaturesResponse
from rime_sdk.swagger.swagger_client.models.rime_list_file_scan_results_response import RimeListFileScanResultsResponse
from rime_sdk.swagger.swagger_client.models.rime_list_firewall_instances_response import RimeListFirewallInstancesResponse
from rime_sdk.swagger.swagger_client.models.rime_list_gai_test_job_response import RimeListGAITestJobResponse
from rime_sdk.swagger.swagger_client.models.rime_list_gai_test_jobs_request_query import RimeListGAITestJobsRequestQuery
from rime_sdk.swagger.swagger_client.models.rime_list_images_request import RimeListImagesRequest
from rime_sdk.swagger.swagger_client.models.rime_list_images_response import RimeListImagesResponse
from rime_sdk.swagger.swagger_client.models.rime_list_jobs_for_project_request_query import RimeListJobsForProjectRequestQuery
from rime_sdk.swagger.swagger_client.models.rime_list_jobs_for_project_response import RimeListJobsForProjectResponse
from rime_sdk.swagger.swagger_client.models.rime_list_metric_identifiers_response import RimeListMetricIdentifiersResponse
from rime_sdk.swagger.swagger_client.models.rime_list_model_cards_response import RimeListModelCardsResponse
from rime_sdk.swagger.swagger_client.models.rime_list_models_response import RimeListModelsResponse
from rime_sdk.swagger.swagger_client.models.rime_list_monitors_response import RimeListMonitorsResponse
from rime_sdk.swagger.swagger_client.models.rime_list_notifications_response import RimeListNotificationsResponse
from rime_sdk.swagger.swagger_client.models.rime_list_prediction_sets_response import RimeListPredictionSetsResponse
from rime_sdk.swagger.swagger_client.models.rime_list_project_tags_in_workspace_response import RimeListProjectTagsInWorkspaceResponse
from rime_sdk.swagger.swagger_client.models.rime_list_uploaded_file_urls_response import RimeListUploadedFileURLsResponse
from rime_sdk.swagger.swagger_client.models.rime_list_users_of_workspace_response import RimeListUsersOfWorkspaceResponse
from rime_sdk.swagger.swagger_client.models.rime_list_users_request_query import RimeListUsersRequestQuery
from rime_sdk.swagger.swagger_client.models.rime_list_users_response import RimeListUsersResponse
from rime_sdk.swagger.swagger_client.models.rime_list_workspace_integrations_response import RimeListWorkspaceIntegrationsResponse
from rime_sdk.swagger.swagger_client.models.rime_list_workspaces_request_query import RimeListWorkspacesRequestQuery
from rime_sdk.swagger.swagger_client.models.rime_list_workspaces_response import RimeListWorkspacesResponse
from rime_sdk.swagger.swagger_client.models.rime_long_description_tab import RimeLongDescriptionTab
from rime_sdk.swagger.swagger_client.models.rime_managed_image import RimeManagedImage
from rime_sdk.swagger.swagger_client.models.rime_managed_image_package_type import RimeManagedImagePackageType
from rime_sdk.swagger.swagger_client.models.rime_managed_image_status import RimeManagedImageStatus
from rime_sdk.swagger.swagger_client.models.rime_model_card import RimeModelCard
from rime_sdk.swagger.swagger_client.models.rime_model_task import RimeModelTask
from rime_sdk.swagger.swagger_client.models.rime_model_with_owner_details import RimeModelWithOwnerDetails
from rime_sdk.swagger.swagger_client.models.rime_monitor_data_point import RimeMonitorDataPoint
from rime_sdk.swagger.swagger_client.models.rime_named_double import RimeNamedDouble
from rime_sdk.swagger.swagger_client.models.rime_order import RimeOrder
from rime_sdk.swagger.swagger_client.models.rime_parent_role_subject_role_pair import RimeParentRoleSubjectRolePair
from rime_sdk.swagger.swagger_client.models.rime_ri_email_recipient import RimeRIEmailRecipient
from rime_sdk.swagger.swagger_client.models.rime_ri_plan import RimeRIPlan
from rime_sdk.swagger.swagger_client.models.rime_register_data_stream_response import RimeRegisterDataStreamResponse
from rime_sdk.swagger.swagger_client.models.rime_register_dataset_response import RimeRegisterDatasetResponse
from rime_sdk.swagger.swagger_client.models.rime_register_external_agent_request import RimeRegisterExternalAgentRequest
from rime_sdk.swagger.swagger_client.models.rime_register_firewall_agent_request import RimeRegisterFirewallAgentRequest
from rime_sdk.swagger.swagger_client.models.rime_register_firewall_agent_response import RimeRegisterFirewallAgentResponse
from rime_sdk.swagger.swagger_client.models.rime_register_model_response import RimeRegisterModelResponse
from rime_sdk.swagger.swagger_client.models.rime_register_prediction_set_response import RimeRegisterPredictionSetResponse
from rime_sdk.swagger.swagger_client.models.rime_remove_user_from_workspace_response import RimeRemoveUserFromWorkspaceResponse
from rime_sdk.swagger.swagger_client.models.rime_repo_metadata import RimeRepoMetadata
from rime_sdk.swagger.swagger_client.models.rime_repo_metadata_license import RimeRepoMetadataLicense
from rime_sdk.swagger.swagger_client.models.rime_repo_metadata_reputation import RimeRepoMetadataReputation
from rime_sdk.swagger.swagger_client.models.rime_repo_type import RimeRepoType
from rime_sdk.swagger.swagger_client.models.rime_reset_password_response import RimeResetPasswordResponse
from rime_sdk.swagger.swagger_client.models.rime_resolve_detection_event_response import RimeResolveDetectionEventResponse
from rime_sdk.swagger.swagger_client.models.rime_safe_url import RimeSafeURL
from rime_sdk.swagger.swagger_client.models.rime_search_spec import RimeSearchSpec
from rime_sdk.swagger.swagger_client.models.rime_send_ri_email_response import RimeSendRIEmailResponse
from rime_sdk.swagger.swagger_client.models.rime_severity import RimeSeverity
from rime_sdk.swagger.swagger_client.models.rime_severity_counts import RimeSeverityCounts
from rime_sdk.swagger.swagger_client.models.rime_sort_spec import RimeSortSpec
from rime_sdk.swagger.swagger_client.models.rime_start_continuous_test_response import RimeStartContinuousTestResponse
from rime_sdk.swagger.swagger_client.models.rime_start_file_scan_request import RimeStartFileScanRequest
from rime_sdk.swagger.swagger_client.models.rime_start_file_scan_response import RimeStartFileScanResponse
from rime_sdk.swagger.swagger_client.models.rime_start_stress_test_response import RimeStartStressTestResponse
from rime_sdk.swagger.swagger_client.models.rime_start_validate_dataset_task_request import RimeStartValidateDatasetTaskRequest
from rime_sdk.swagger.swagger_client.models.rime_start_validate_dataset_task_response import RimeStartValidateDatasetTaskResponse
from rime_sdk.swagger.swagger_client.models.rime_start_validate_model_task_request import RimeStartValidateModelTaskRequest
from rime_sdk.swagger.swagger_client.models.rime_start_validate_model_task_response import RimeStartValidateModelTaskResponse
from rime_sdk.swagger.swagger_client.models.rime_start_validate_predictions_task_request import RimeStartValidatePredictionsTaskRequest
from rime_sdk.swagger.swagger_client.models.rime_start_validate_predictions_task_response import RimeStartValidatePredictionsTaskResponse
from rime_sdk.swagger.swagger_client.models.rime_store_datapoints_response import RimeStoreDatapointsResponse
from rime_sdk.swagger.swagger_client.models.rime_store_predictions_request_prediction import RimeStorePredictionsRequestPrediction
from rime_sdk.swagger.swagger_client.models.rime_store_predictions_response import RimeStorePredictionsResponse
from rime_sdk.swagger.swagger_client.models.rime_str_list import RimeStrList
from rime_sdk.swagger.swagger_client.models.rime_stress_test_job_progress import RimeStressTestJobProgress
from rime_sdk.swagger.swagger_client.models.rime_subject_type import RimeSubjectType
from rime_sdk.swagger.swagger_client.models.rime_suggestion import RimeSuggestion
from rime_sdk.swagger.swagger_client.models.rime_sync_image_tag_response import RimeSyncImageTagResponse
from rime_sdk.swagger.swagger_client.models.rime_table_column import RimeTableColumn
from rime_sdk.swagger.swagger_client.models.rime_table_column_type import RimeTableColumnType
from rime_sdk.swagger.swagger_client.models.rime_test_case_monitor_info import RimeTestCaseMonitorInfo
from rime_sdk.swagger.swagger_client.models.rime_test_case_status import RimeTestCaseStatus
from rime_sdk.swagger.swagger_client.models.rime_test_metric import RimeTestMetric
from rime_sdk.swagger.swagger_client.models.rime_test_metric_category import RimeTestMetricCategory
from rime_sdk.swagger.swagger_client.models.rime_test_run_progress import RimeTestRunProgress
from rime_sdk.swagger.swagger_client.models.rime_test_task_status import RimeTestTaskStatus
from rime_sdk.swagger.swagger_client.models.rime_test_type import RimeTestType
from rime_sdk.swagger.swagger_client.models.rime_time_interval import RimeTimeInterval
from rime_sdk.swagger.swagger_client.models.rime_token_type import RimeTokenType
from rime_sdk.swagger.swagger_client.models.rime_toxicity_threat_category import RimeToxicityThreatCategory
from rime_sdk.swagger.swagger_client.models.rime_uuid import RimeUUID
from rime_sdk.swagger.swagger_client.models.rime_update_build_info_request import RimeUpdateBuildInfoRequest
from rime_sdk.swagger.swagger_client.models.rime_update_build_info_response import RimeUpdateBuildInfoResponse
from rime_sdk.swagger.swagger_client.models.rime_update_firewall_response import RimeUpdateFirewallResponse
from rime_sdk.swagger.swagger_client.models.rime_update_integration_response import RimeUpdateIntegrationResponse
from rime_sdk.swagger.swagger_client.models.rime_update_model_card_response import RimeUpdateModelCardResponse
from rime_sdk.swagger.swagger_client.models.rime_update_monitor_response import RimeUpdateMonitorResponse
from rime_sdk.swagger.swagger_client.models.rime_update_notification_response import RimeUpdateNotificationResponse
from rime_sdk.swagger.swagger_client.models.rime_update_schedule_response import RimeUpdateScheduleResponse
from rime_sdk.swagger.swagger_client.models.rime_update_upgrade_status_for_agent_response import RimeUpdateUpgradeStatusForAgentResponse
from rime_sdk.swagger.swagger_client.models.rime_update_user_of_workspace_response import RimeUpdateUserOfWorkspaceResponse
from rime_sdk.swagger.swagger_client.models.rime_update_user_response import RimeUpdateUserResponse
from rime_sdk.swagger.swagger_client.models.rime_update_workspace_response import RimeUpdateWorkspaceResponse
from rime_sdk.swagger.swagger_client.models.rime_upgrade_agent_response import RimeUpgradeAgentResponse
from rime_sdk.swagger.swagger_client.models.rime_upgrade_status import RimeUpgradeStatus
from rime_sdk.swagger.swagger_client.models.rime_upsert_feature_flags_response import RimeUpsertFeatureFlagsResponse
from rime_sdk.swagger.swagger_client.models.rime_user_detail_with_role import RimeUserDetailWithRole
from rime_sdk.swagger.swagger_client.models.rime_user_role import RimeUserRole
from rime_sdk.swagger.swagger_client.models.rime_user_with_role import RimeUserWithRole
from rime_sdk.swagger.swagger_client.models.rime_user_write_mask import RimeUserWriteMask
from rime_sdk.swagger.swagger_client.models.rime_validate_test_config_response import RimeValidateTestConfigResponse
from rime_sdk.swagger.swagger_client.models.rime_workspace import RimeWorkspace
from rime_sdk.swagger.swagger_client.models.rime_workspace_write_mask import RimeWorkspaceWriteMask
from rime_sdk.swagger.swagger_client.models.rischemaintegration_integration import RischemaintegrationIntegration
from rime_sdk.swagger.swagger_client.models.riskscore_risk_category_type import RiskscoreRiskCategoryType
from rime_sdk.swagger.swagger_client.models.riskscore_risk_score import RiskscoreRiskScore
from rime_sdk.swagger.swagger_client.models.role_users_body import RoleUsersBody
from rime_sdk.swagger.swagger_client.models.role_workspace_body import RoleWorkspaceBody
from rime_sdk.swagger.swagger_client.models.rule_evaluation_metadata_yara_info import RuleEvaluationMetadataYaraInfo
from rime_sdk.swagger.swagger_client.models.rule_output_rule_evaluation_metadata import RuleOutputRuleEvaluationMetadata
from rime_sdk.swagger.swagger_client.models.rule_output_rule_evaluation_metadata_model_info import RuleOutputRuleEvaluationMetadataModelInfo
from rime_sdk.swagger.swagger_client.models.runtimeinfo_custom_image import RuntimeinfoCustomImage
from rime_sdk.swagger.swagger_client.models.runtimeinfo_custom_image_type import RuntimeinfoCustomImageType
from rime_sdk.swagger.swagger_client.models.runtimeinfo_resource_request import RuntimeinfoResourceRequest
from rime_sdk.swagger.swagger_client.models.runtimeinfo_run_time_info import RuntimeinfoRunTimeInfo
from rime_sdk.swagger.swagger_client.models.schedule_id_uuid_activate_body import ScheduleIdUuidActivateBody
from rime_sdk.swagger.swagger_client.models.schedule_id_uuid_deactivate_body import ScheduleIdUuidDeactivateBody
from rime_sdk.swagger.swagger_client.models.schedule_schedule import ScheduleSchedule
from rime_sdk.swagger.swagger_client.models.schedules_schedule_schedule_id_uuid_body import SchedulesScheduleScheduleIdUuidBody
from rime_sdk.swagger.swagger_client.models.schemadatacollector_prediction import SchemadatacollectorPrediction
from rime_sdk.swagger.swagger_client.models.schemafilescanning_file_scan_result import SchemafilescanningFileScanResult
from rime_sdk.swagger.swagger_client.models.schemafilescanning_file_security_report import SchemafilescanningFileSecurityReport
from rime_sdk.swagger.swagger_client.models.schemafilescanning_package_type import SchemafilescanningPackageType
from rime_sdk.swagger.swagger_client.models.schemafilescanning_repo_metadata import SchemafilescanningRepoMetadata
from rime_sdk.swagger.swagger_client.models.schemafilescanning_repo_metadata_license import SchemafilescanningRepoMetadataLicense
from rime_sdk.swagger.swagger_client.models.schemafilescanning_repo_metadata_reputation import SchemafilescanningRepoMetadataReputation
from rime_sdk.swagger.swagger_client.models.schemaintegration_integration_variable import SchemaintegrationIntegrationVariable
from rime_sdk.swagger.swagger_client.models.schemamonitor_config import SchemamonitorConfig
from rime_sdk.swagger.swagger_client.models.schemanotification_config import SchemanotificationConfig
from rime_sdk.swagger.swagger_client.models.schemaregistry_model_info import SchemaregistryModelInfo
from rime_sdk.swagger.swagger_client.models.security_event_details_flagged_datapoint import SecurityEventDetailsFlaggedDatapoint
from rime_sdk.swagger.swagger_client.models.security_event_details_security_event_type import SecurityEventDetailsSecurityEventType
from rime_sdk.swagger.swagger_client.models.statedb_archived_job_logs import StatedbArchivedJobLogs
from rime_sdk.swagger.swagger_client.models.statedb_job_status import StatedbJobStatus
from rime_sdk.swagger.swagger_client.models.stream_result_of_rime_get_datapoints_response import StreamResultOfRimeGetDatapointsResponse
from rime_sdk.swagger.swagger_client.models.stream_result_of_rime_get_latest_logs_response import StreamResultOfRimeGetLatestLogsResponse
from rime_sdk.swagger.swagger_client.models.stream_result_of_rime_get_predictions_response import StreamResultOfRimeGetPredictionsResponse
from rime_sdk.swagger.swagger_client.models.stresstests_project_id_uuid_body import StresstestsProjectIdUuidBody
from rime_sdk.swagger.swagger_client.models.test_run_metrics_category_summary_metric import TestRunMetricsCategorySummaryMetric
from rime_sdk.swagger.swagger_client.models.test_run_metrics_model_perf_metric import TestRunMetricsModelPerfMetric
from rime_sdk.swagger.swagger_client.models.test_run_progress_test_batch_progress import TestRunProgressTestBatchProgress
from rime_sdk.swagger.swagger_client.models.testrun_annotated_test_config import TestrunAnnotatedTestConfig
from rime_sdk.swagger.swagger_client.models.testrun_custom_metric import TestrunCustomMetric
from rime_sdk.swagger.swagger_client.models.testrun_data_profiling import TestrunDataProfiling
from rime_sdk.swagger.swagger_client.models.testrun_model_profiling import TestrunModelProfiling
from rime_sdk.swagger.swagger_client.models.testrun_profiling_config import TestrunProfilingConfig
from rime_sdk.swagger.swagger_client.models.testrun_ref_eval_datasets import TestrunRefEvalDatasets
from rime_sdk.swagger.swagger_client.models.testrun_test_category_type import TestrunTestCategoryType
from rime_sdk.swagger.swagger_client.models.testrun_test_run_config import TestrunTestRunConfig
from rime_sdk.swagger.swagger_client.models.testrun_test_run_incremental_config import TestrunTestRunIncrementalConfig
from rime_sdk.swagger.swagger_client.models.testrun_test_sensitivity import TestrunTestSensitivity
from rime_sdk.swagger.swagger_client.models.testrun_test_suite_config import TestrunTestSuiteConfig
from rime_sdk.swagger.swagger_client.models.testrunresult_get_batch_result_response import TestrunresultGetBatchResultResponse
from rime_sdk.swagger.swagger_client.models.testrunresult_get_category_results_response import TestrunresultGetCategoryResultsResponse
from rime_sdk.swagger.swagger_client.models.testrunresult_get_feature_result_response import TestrunresultGetFeatureResultResponse
from rime_sdk.swagger.swagger_client.models.testrunresult_get_test_config_response import TestrunresultGetTestConfigResponse
from rime_sdk.swagger.swagger_client.models.testrunresult_get_test_run_response import TestrunresultGetTestRunResponse
from rime_sdk.swagger.swagger_client.models.testrunresult_list_batch_results_response import TestrunresultListBatchResultsResponse
from rime_sdk.swagger.swagger_client.models.testrunresult_list_feature_results_response import TestrunresultListFeatureResultsResponse
from rime_sdk.swagger.swagger_client.models.testrunresult_list_monitor_categories_response import TestrunresultListMonitorCategoriesResponse
from rime_sdk.swagger.swagger_client.models.testrunresult_list_summary_tests_response import TestrunresultListSummaryTestsResponse
from rime_sdk.swagger.swagger_client.models.testrunresult_list_test_cases_response import TestrunresultListTestCasesResponse
from rime_sdk.swagger.swagger_client.models.testrunresult_list_test_runs_request_query import TestrunresultListTestRunsRequestQuery
from rime_sdk.swagger.swagger_client.models.testrunresult_list_test_runs_response import TestrunresultListTestRunsResponse
from rime_sdk.swagger.swagger_client.models.testrunresult_list_validation_categories_response import TestrunresultListValidationCategoriesResponse
from rime_sdk.swagger.swagger_client.models.testrunresult_rename_test_run_response import TestrunresultRenameTestRunResponse
from rime_sdk.swagger.swagger_client.models.testrunresult_result_summary_counts import TestrunresultResultSummaryCounts
from rime_sdk.swagger.swagger_client.models.testrunresult_test_batch_result import TestrunresultTestBatchResult
from rime_sdk.swagger.swagger_client.models.testrunresult_test_batch_result_display import TestrunresultTestBatchResultDisplay
from rime_sdk.swagger.swagger_client.models.testrunresult_test_case import TestrunresultTestCase
from rime_sdk.swagger.swagger_client.models.testrunresult_test_case_display import TestrunresultTestCaseDisplay
from rime_sdk.swagger.swagger_client.models.testrunresult_test_feature_result import TestrunresultTestFeatureResult
from rime_sdk.swagger.swagger_client.models.testrunresult_test_feature_result_display import TestrunresultTestFeatureResultDisplay
from rime_sdk.swagger.swagger_client.models.testrunresult_test_run_detail import TestrunresultTestRunDetail
from rime_sdk.swagger.swagger_client.models.testrunresult_test_run_metrics import TestrunresultTestRunMetrics
from rime_sdk.swagger.swagger_client.models.user_favorite_projects import UserFavoriteProjects
from rime_sdk.swagger.swagger_client.models.user_private_info import UserPrivateInfo
from rime_sdk.swagger.swagger_client.models.user_role import UserRole
from rime_sdk.swagger.swagger_client.models.user_user_detail import UserUserDetail
from rime_sdk.swagger.swagger_client.models.users_user_id_uuid_body import UsersUserIdUuidBody
from rime_sdk.swagger.swagger_client.models.users_user_user_id_uuid_body import UsersUserUserIdUuidBody
from rime_sdk.swagger.swagger_client.models.users_user_user_id_uuid_body1 import UsersUserUserIdUuidBody1
from rime_sdk.swagger.swagger_client.models.v1betaintegrationsintegration_id_uuid_integration import V1betaintegrationsintegrationIdUuidIntegration
from rime_sdk.swagger.swagger_client.models.v1betamodelcardsmodel_card_model_card_id_uuid_model_card import V1betamodelcardsmodelCardModelCardIdUuidModelCard
from rime_sdk.swagger.swagger_client.models.v1betamonitorsmonitor_id_uuid_monitor import V1betamonitorsmonitorIdUuidMonitor
from rime_sdk.swagger.swagger_client.models.v1firewallfirewall_firewall_id_uuid_firewall import V1firewallfirewallFirewallIdUuidFirewall
from rime_sdk.swagger.swagger_client.models.v1notifsettingsnotification_id_uuid_notification import V1notifsettingsnotificationIdUuidNotification
from rime_sdk.swagger.swagger_client.models.v1projectsproject_id_uuidroleusersuser_user_id_uuid_user import V1projectsprojectIdUuidroleusersuserUserIdUuidUser
from rime_sdk.swagger.swagger_client.models.v1usersuser_id_uuid_user import V1usersuserIdUuidUser
from rime_sdk.swagger.swagger_client.models.v1workspaceworkspace_workspace_id_uuid_workspace import V1workspaceworkspaceWorkspaceIdUuidWorkspace
from rime_sdk.swagger.swagger_client.models.validate_response_processed_request import ValidateResponseProcessedRequest
from rime_sdk.swagger.swagger_client.models.validate_response_product_metadata import ValidateResponseProductMetadata
from rime_sdk.swagger.swagger_client.models.validation_validate_dataset_response import ValidationValidateDatasetResponse
from rime_sdk.swagger.swagger_client.models.validation_validate_model_response import ValidationValidateModelResponse
from rime_sdk.swagger.swagger_client.models.validation_validate_predictions_response import ValidationValidatePredictionsResponse
from rime_sdk.swagger.swagger_client.models.workspace_id_uuid_users_body import WorkspaceIdUuidUsersBody
from rime_sdk.swagger.swagger_client.models.workspace_workspace_workspace_id_uuid_body import WorkspaceWorkspaceWorkspaceIdUuidBody



"""Library defining the interface to work with generative models."""
from typing import Iterator, Optional

from rime_sdk.internal.rest_error_handler import RESTErrorHandler
from rime_sdk.job import GenerativeModelTestJob
from rime_sdk.swagger.swagger_client import (
    ApiClient,
    GenerativeModelTestingApi,
    GenerativetestingGenerativeTestingResult,
    GenerativetestingGetGenerativeModelTestResultsResponse,
    GenerativetestingStartGenerativeModelTestRequest,
    GenerativetestingStartGenerativeModelTestResponse,
    RimeUUID,
)


class GenerativeModel:
    """The interface to the Generative Model Testing API."""

    def __init__(self, api_client: ApiClient):
        """Initialize the Generative Model interface.

        Args:
            api_client: The API client to use.
        """
        self._api_client = api_client

    def start_test(
        self,
        url: str,
        endpoint_payload_template: str,
        response_json_path: str,
        http_headers: Optional[dict] = None,
        name: Optional[str] = None,
        http_auth_integration_id: Optional[str] = None,
        mutual_tls_integration_id: Optional[str] = None,
    ) -> GenerativeModelTestJob:
        """Start a Generative Model Test.

        Args:
            url: The URL to test.
            http_headers: The HTTP headers to use.
            endpoint_payload_template: The endpoint payload template to use.
            response_json_path: The response JSON path to use.
            name: A name to identify your generative test run.
            http_auth_integration_id: The HTTP Auth Integration ID.
            mutual_tls_integration_id: The Mutual TLS Integration ID.

        Returns:
            GenerativeModelTestJob: The Generative Model Test Job.
        """
        http_auth_uuid = (
            RimeUUID(http_auth_integration_id)
            if http_auth_integration_id is not None
            else None
        )
        mtls_uuid = (
            RimeUUID(mutual_tls_integration_id)
            if mutual_tls_integration_id is not None
            else None
        )

        request = GenerativetestingStartGenerativeModelTestRequest(
            url=url,
            http_headers=http_headers,
            endpoint_payload_template=endpoint_payload_template,
            response_json_path=response_json_path,
            name=name,
            http_auth_integration_id=http_auth_uuid,
            mutual_tls_integration_id=mtls_uuid,
        )
        with RESTErrorHandler():
            res: GenerativetestingStartGenerativeModelTestResponse = (
                GenerativeModelTestingApi(self._api_client).start_generative_test(
                    body=request
                )
            )
            if res.job_id is None:
                raise ValueError(
                    "Job ID is missing from the response, please try making the request again."
                )

            return GenerativeModelTestJob(self._api_client, res.job_id.uuid)

    def get_results(
        self,
        job_id_uuid: str,
        page_size: Optional[int] = 10,
    ) -> Iterator[GenerativetestingGenerativeTestingResult]:
        """Get the results of a Generative Model Test.

        Args:
            job_id_uuid: The job ID UUID.
            page_size: The number of results per request.  Defaults to 10.

        Returns:
            An iterator of Generative Model Test Results.
        """
        page_token = ""
        with RESTErrorHandler():
            while True:
                res: GenerativetestingGetGenerativeModelTestResultsResponse = (
                    GenerativeModelTestingApi(self._api_client).results(
                        job_id_uuid=job_id_uuid,
                        page_token=page_token,
                        page_size=page_size,
                    )
                )

                yield from res.results

                if not res.has_more:
                    break

                page_token = res.next_page_token



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class GenerativetestingGenerativeTestingResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'RimeUUID',
        'job_id': 'RimeUUID',
        'attack_technique': 'str',
        'attack_objective': 'RimeAttackObjective',
        'objective_sub_category': 'GenerativetestingObjectiveSubCategory',
        'failing_examples': 'list[GenerativeTestingResultExample]',
        'severity': 'LibgenerativeSeverity',
        'owasp_standards': 'list[GenerativetestingGenerativeTestingResultStandardInfo]',
        'nist_standards': 'list[GenerativetestingGenerativeTestingResultStandardInfo]',
        'mitre_standards': 'list[GenerativetestingGenerativeTestingResultStandardInfo]',
        'attacks_attempted': 'int',
        'threat': 'GenerativetestingThreat'
    }

    attribute_map = {
        'id': 'id',
        'job_id': 'jobId',
        'attack_technique': 'attackTechnique',
        'attack_objective': 'attackObjective',
        'objective_sub_category': 'objectiveSubCategory',
        'failing_examples': 'failingExamples',
        'severity': 'severity',
        'owasp_standards': 'owaspStandards',
        'nist_standards': 'nistStandards',
        'mitre_standards': 'mitreStandards',
        'attacks_attempted': 'attacksAttempted',
        'threat': 'threat'
    }

    def __init__(self, id=None, job_id=None, attack_technique=None, attack_objective=None, objective_sub_category=None, failing_examples=None, severity=None, owasp_standards=None, nist_standards=None, mitre_standards=None, attacks_attempted=None, threat=None):  # noqa: E501
        """GenerativetestingGenerativeTestingResult - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._job_id = None
        self._attack_technique = None
        self._attack_objective = None
        self._objective_sub_category = None
        self._failing_examples = None
        self._severity = None
        self._owasp_standards = None
        self._nist_standards = None
        self._mitre_standards = None
        self._attacks_attempted = None
        self._threat = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if job_id is not None:
            self.job_id = job_id
        if attack_technique is not None:
            self.attack_technique = attack_technique
        if attack_objective is not None:
            self.attack_objective = attack_objective
        if objective_sub_category is not None:
            self.objective_sub_category = objective_sub_category
        if failing_examples is not None:
            self.failing_examples = failing_examples
        if severity is not None:
            self.severity = severity
        if owasp_standards is not None:
            self.owasp_standards = owasp_standards
        if nist_standards is not None:
            self.nist_standards = nist_standards
        if mitre_standards is not None:
            self.mitre_standards = mitre_standards
        if attacks_attempted is not None:
            self.attacks_attempted = attacks_attempted
        if threat is not None:
            self.threat = threat

    @property
    def id(self):
        """Gets the id of this GenerativetestingGenerativeTestingResult.  # noqa: E501


        :return: The id of this GenerativetestingGenerativeTestingResult.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this GenerativetestingGenerativeTestingResult.


        :param id: The id of this GenerativetestingGenerativeTestingResult.  # noqa: E501
        :type: RimeUUID
        """

        self._id = id

    @property
    def job_id(self):
        """Gets the job_id of this GenerativetestingGenerativeTestingResult.  # noqa: E501


        :return: The job_id of this GenerativetestingGenerativeTestingResult.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this GenerativetestingGenerativeTestingResult.


        :param job_id: The job_id of this GenerativetestingGenerativeTestingResult.  # noqa: E501
        :type: RimeUUID
        """

        self._job_id = job_id

    @property
    def attack_technique(self):
        """Gets the attack_technique of this GenerativetestingGenerativeTestingResult.  # noqa: E501

        The attack technique used in the prompt. This is a string because the types of attacks changes frequently over time depending on our threat intelligence.  # noqa: E501

        :return: The attack_technique of this GenerativetestingGenerativeTestingResult.  # noqa: E501
        :rtype: str
        """
        return self._attack_technique

    @attack_technique.setter
    def attack_technique(self, attack_technique):
        """Sets the attack_technique of this GenerativetestingGenerativeTestingResult.

        The attack technique used in the prompt. This is a string because the types of attacks changes frequently over time depending on our threat intelligence.  # noqa: E501

        :param attack_technique: The attack_technique of this GenerativetestingGenerativeTestingResult.  # noqa: E501
        :type: str
        """

        self._attack_technique = attack_technique

    @property
    def attack_objective(self):
        """Gets the attack_objective of this GenerativetestingGenerativeTestingResult.  # noqa: E501


        :return: The attack_objective of this GenerativetestingGenerativeTestingResult.  # noqa: E501
        :rtype: RimeAttackObjective
        """
        return self._attack_objective

    @attack_objective.setter
    def attack_objective(self, attack_objective):
        """Sets the attack_objective of this GenerativetestingGenerativeTestingResult.


        :param attack_objective: The attack_objective of this GenerativetestingGenerativeTestingResult.  # noqa: E501
        :type: RimeAttackObjective
        """

        self._attack_objective = attack_objective

    @property
    def objective_sub_category(self):
        """Gets the objective_sub_category of this GenerativetestingGenerativeTestingResult.  # noqa: E501


        :return: The objective_sub_category of this GenerativetestingGenerativeTestingResult.  # noqa: E501
        :rtype: GenerativetestingObjectiveSubCategory
        """
        return self._objective_sub_category

    @objective_sub_category.setter
    def objective_sub_category(self, objective_sub_category):
        """Sets the objective_sub_category of this GenerativetestingGenerativeTestingResult.


        :param objective_sub_category: The objective_sub_category of this GenerativetestingGenerativeTestingResult.  # noqa: E501
        :type: GenerativetestingObjectiveSubCategory
        """

        self._objective_sub_category = objective_sub_category

    @property
    def failing_examples(self):
        """Gets the failing_examples of this GenerativetestingGenerativeTestingResult.  # noqa: E501

        List of failing examples to demonstrate failures in this category.  # noqa: E501

        :return: The failing_examples of this GenerativetestingGenerativeTestingResult.  # noqa: E501
        :rtype: list[GenerativeTestingResultExample]
        """
        return self._failing_examples

    @failing_examples.setter
    def failing_examples(self, failing_examples):
        """Sets the failing_examples of this GenerativetestingGenerativeTestingResult.

        List of failing examples to demonstrate failures in this category.  # noqa: E501

        :param failing_examples: The failing_examples of this GenerativetestingGenerativeTestingResult.  # noqa: E501
        :type: list[GenerativeTestingResultExample]
        """

        self._failing_examples = failing_examples

    @property
    def severity(self):
        """Gets the severity of this GenerativetestingGenerativeTestingResult.  # noqa: E501


        :return: The severity of this GenerativetestingGenerativeTestingResult.  # noqa: E501
        :rtype: LibgenerativeSeverity
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """Sets the severity of this GenerativetestingGenerativeTestingResult.


        :param severity: The severity of this GenerativetestingGenerativeTestingResult.  # noqa: E501
        :type: LibgenerativeSeverity
        """

        self._severity = severity

    @property
    def owasp_standards(self):
        """Gets the owasp_standards of this GenerativetestingGenerativeTestingResult.  # noqa: E501

        Containers describing the various AI risk standards associated with this batch of attack examples.  # noqa: E501

        :return: The owasp_standards of this GenerativetestingGenerativeTestingResult.  # noqa: E501
        :rtype: list[GenerativetestingGenerativeTestingResultStandardInfo]
        """
        return self._owasp_standards

    @owasp_standards.setter
    def owasp_standards(self, owasp_standards):
        """Sets the owasp_standards of this GenerativetestingGenerativeTestingResult.

        Containers describing the various AI risk standards associated with this batch of attack examples.  # noqa: E501

        :param owasp_standards: The owasp_standards of this GenerativetestingGenerativeTestingResult.  # noqa: E501
        :type: list[GenerativetestingGenerativeTestingResultStandardInfo]
        """

        self._owasp_standards = owasp_standards

    @property
    def nist_standards(self):
        """Gets the nist_standards of this GenerativetestingGenerativeTestingResult.  # noqa: E501


        :return: The nist_standards of this GenerativetestingGenerativeTestingResult.  # noqa: E501
        :rtype: list[GenerativetestingGenerativeTestingResultStandardInfo]
        """
        return self._nist_standards

    @nist_standards.setter
    def nist_standards(self, nist_standards):
        """Sets the nist_standards of this GenerativetestingGenerativeTestingResult.


        :param nist_standards: The nist_standards of this GenerativetestingGenerativeTestingResult.  # noqa: E501
        :type: list[GenerativetestingGenerativeTestingResultStandardInfo]
        """

        self._nist_standards = nist_standards

    @property
    def mitre_standards(self):
        """Gets the mitre_standards of this GenerativetestingGenerativeTestingResult.  # noqa: E501


        :return: The mitre_standards of this GenerativetestingGenerativeTestingResult.  # noqa: E501
        :rtype: list[GenerativetestingGenerativeTestingResultStandardInfo]
        """
        return self._mitre_standards

    @mitre_standards.setter
    def mitre_standards(self, mitre_standards):
        """Sets the mitre_standards of this GenerativetestingGenerativeTestingResult.


        :param mitre_standards: The mitre_standards of this GenerativetestingGenerativeTestingResult.  # noqa: E501
        :type: list[GenerativetestingGenerativeTestingResultStandardInfo]
        """

        self._mitre_standards = mitre_standards

    @property
    def attacks_attempted(self):
        """Gets the attacks_attempted of this GenerativetestingGenerativeTestingResult.  # noqa: E501

        The number of attacks prompts attempted for these results.  # noqa: E501

        :return: The attacks_attempted of this GenerativetestingGenerativeTestingResult.  # noqa: E501
        :rtype: int
        """
        return self._attacks_attempted

    @attacks_attempted.setter
    def attacks_attempted(self, attacks_attempted):
        """Sets the attacks_attempted of this GenerativetestingGenerativeTestingResult.

        The number of attacks prompts attempted for these results.  # noqa: E501

        :param attacks_attempted: The attacks_attempted of this GenerativetestingGenerativeTestingResult.  # noqa: E501
        :type: int
        """

        self._attacks_attempted = attacks_attempted

    @property
    def threat(self):
        """Gets the threat of this GenerativetestingGenerativeTestingResult.  # noqa: E501


        :return: The threat of this GenerativetestingGenerativeTestingResult.  # noqa: E501
        :rtype: GenerativetestingThreat
        """
        return self._threat

    @threat.setter
    def threat(self, threat):
        """Sets the threat of this GenerativetestingGenerativeTestingResult.


        :param threat: The threat of this GenerativetestingGenerativeTestingResult.  # noqa: E501
        :type: GenerativetestingThreat
        """

        self._threat = threat

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GenerativetestingGenerativeTestingResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GenerativetestingGenerativeTestingResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ProjectProject(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'RimeUUID',
        'name': 'str',
        'description': 'str',
        'use_case': 'str',
        'ethical_consideration': 'str',
        'creation_time': 'datetime',
        'owner_id': 'RimeUUID',
        'workspace_id': 'RimeUUID',
        'model_task': 'RimeModelTask',
        'tags': 'list[str]',
        'firewall_ids': 'list[RimeUUID]',
        'project_test_suite_config': 'TestrunTestSuiteConfig',
        'profiling_config': 'TestrunProfilingConfig',
        'run_time_info': 'RuntimeinfoRunTimeInfo',
        'is_published': 'bool',
        'last_test_run_time': 'datetime',
        'stress_test_categories': 'list[TestrunTestCategoryType]',
        'continuous_test_categories': 'list[TestrunTestCategoryType]',
        'risk_scores': 'list[RiskscoreRiskScore]',
        'active_schedule': 'ProjectScheduleInfo'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'description': 'description',
        'use_case': 'useCase',
        'ethical_consideration': 'ethicalConsideration',
        'creation_time': 'creationTime',
        'owner_id': 'ownerId',
        'workspace_id': 'workspaceId',
        'model_task': 'modelTask',
        'tags': 'tags',
        'firewall_ids': 'firewallIds',
        'project_test_suite_config': 'projectTestSuiteConfig',
        'profiling_config': 'profilingConfig',
        'run_time_info': 'runTimeInfo',
        'is_published': 'isPublished',
        'last_test_run_time': 'lastTestRunTime',
        'stress_test_categories': 'stressTestCategories',
        'continuous_test_categories': 'continuousTestCategories',
        'risk_scores': 'riskScores',
        'active_schedule': 'activeSchedule'
    }

    def __init__(self, id=None, name=None, description=None, use_case=None, ethical_consideration=None, creation_time=None, owner_id=None, workspace_id=None, model_task=None, tags=None, firewall_ids=None, project_test_suite_config=None, profiling_config=None, run_time_info=None, is_published=None, last_test_run_time=None, stress_test_categories=None, continuous_test_categories=None, risk_scores=None, active_schedule=None):  # noqa: E501
        """ProjectProject - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._description = None
        self._use_case = None
        self._ethical_consideration = None
        self._creation_time = None
        self._owner_id = None
        self._workspace_id = None
        self._model_task = None
        self._tags = None
        self._firewall_ids = None
        self._project_test_suite_config = None
        self._profiling_config = None
        self._run_time_info = None
        self._is_published = None
        self._last_test_run_time = None
        self._stress_test_categories = None
        self._continuous_test_categories = None
        self._risk_scores = None
        self._active_schedule = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if use_case is not None:
            self.use_case = use_case
        if ethical_consideration is not None:
            self.ethical_consideration = ethical_consideration
        if creation_time is not None:
            self.creation_time = creation_time
        if owner_id is not None:
            self.owner_id = owner_id
        if workspace_id is not None:
            self.workspace_id = workspace_id
        if model_task is not None:
            self.model_task = model_task
        if tags is not None:
            self.tags = tags
        if firewall_ids is not None:
            self.firewall_ids = firewall_ids
        if project_test_suite_config is not None:
            self.project_test_suite_config = project_test_suite_config
        if profiling_config is not None:
            self.profiling_config = profiling_config
        if run_time_info is not None:
            self.run_time_info = run_time_info
        if is_published is not None:
            self.is_published = is_published
        if last_test_run_time is not None:
            self.last_test_run_time = last_test_run_time
        if stress_test_categories is not None:
            self.stress_test_categories = stress_test_categories
        if continuous_test_categories is not None:
            self.continuous_test_categories = continuous_test_categories
        if risk_scores is not None:
            self.risk_scores = risk_scores
        if active_schedule is not None:
            self.active_schedule = active_schedule

    @property
    def id(self):
        """Gets the id of this ProjectProject.  # noqa: E501


        :return: The id of this ProjectProject.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ProjectProject.


        :param id: The id of this ProjectProject.  # noqa: E501
        :type: RimeUUID
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this ProjectProject.  # noqa: E501


        :return: The name of this ProjectProject.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ProjectProject.


        :param name: The name of this ProjectProject.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this ProjectProject.  # noqa: E501


        :return: The description of this ProjectProject.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ProjectProject.


        :param description: The description of this ProjectProject.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def use_case(self):
        """Gets the use_case of this ProjectProject.  # noqa: E501


        :return: The use_case of this ProjectProject.  # noqa: E501
        :rtype: str
        """
        return self._use_case

    @use_case.setter
    def use_case(self, use_case):
        """Sets the use_case of this ProjectProject.


        :param use_case: The use_case of this ProjectProject.  # noqa: E501
        :type: str
        """

        self._use_case = use_case

    @property
    def ethical_consideration(self):
        """Gets the ethical_consideration of this ProjectProject.  # noqa: E501


        :return: The ethical_consideration of this ProjectProject.  # noqa: E501
        :rtype: str
        """
        return self._ethical_consideration

    @ethical_consideration.setter
    def ethical_consideration(self, ethical_consideration):
        """Sets the ethical_consideration of this ProjectProject.


        :param ethical_consideration: The ethical_consideration of this ProjectProject.  # noqa: E501
        :type: str
        """

        self._ethical_consideration = ethical_consideration

    @property
    def creation_time(self):
        """Gets the creation_time of this ProjectProject.  # noqa: E501


        :return: The creation_time of this ProjectProject.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """Sets the creation_time of this ProjectProject.


        :param creation_time: The creation_time of this ProjectProject.  # noqa: E501
        :type: datetime
        """

        self._creation_time = creation_time

    @property
    def owner_id(self):
        """Gets the owner_id of this ProjectProject.  # noqa: E501


        :return: The owner_id of this ProjectProject.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._owner_id

    @owner_id.setter
    def owner_id(self, owner_id):
        """Sets the owner_id of this ProjectProject.


        :param owner_id: The owner_id of this ProjectProject.  # noqa: E501
        :type: RimeUUID
        """

        self._owner_id = owner_id

    @property
    def workspace_id(self):
        """Gets the workspace_id of this ProjectProject.  # noqa: E501


        :return: The workspace_id of this ProjectProject.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._workspace_id

    @workspace_id.setter
    def workspace_id(self, workspace_id):
        """Sets the workspace_id of this ProjectProject.


        :param workspace_id: The workspace_id of this ProjectProject.  # noqa: E501
        :type: RimeUUID
        """

        self._workspace_id = workspace_id

    @property
    def model_task(self):
        """Gets the model_task of this ProjectProject.  # noqa: E501


        :return: The model_task of this ProjectProject.  # noqa: E501
        :rtype: RimeModelTask
        """
        return self._model_task

    @model_task.setter
    def model_task(self, model_task):
        """Sets the model_task of this ProjectProject.


        :param model_task: The model_task of this ProjectProject.  # noqa: E501
        :type: RimeModelTask
        """

        self._model_task = model_task

    @property
    def tags(self):
        """Gets the tags of this ProjectProject.  # noqa: E501

        List of tags associated with the Project to help organizing Projects.  # noqa: E501

        :return: The tags of this ProjectProject.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this ProjectProject.

        List of tags associated with the Project to help organizing Projects.  # noqa: E501

        :param tags: The tags of this ProjectProject.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def firewall_ids(self):
        """Gets the firewall_ids of this ProjectProject.  # noqa: E501

        List of Firewall IDs that belong to the Project.  # noqa: E501

        :return: The firewall_ids of this ProjectProject.  # noqa: E501
        :rtype: list[RimeUUID]
        """
        return self._firewall_ids

    @firewall_ids.setter
    def firewall_ids(self, firewall_ids):
        """Sets the firewall_ids of this ProjectProject.

        List of Firewall IDs that belong to the Project.  # noqa: E501

        :param firewall_ids: The firewall_ids of this ProjectProject.  # noqa: E501
        :type: list[RimeUUID]
        """

        self._firewall_ids = firewall_ids

    @property
    def project_test_suite_config(self):
        """Gets the project_test_suite_config of this ProjectProject.  # noqa: E501


        :return: The project_test_suite_config of this ProjectProject.  # noqa: E501
        :rtype: TestrunTestSuiteConfig
        """
        return self._project_test_suite_config

    @project_test_suite_config.setter
    def project_test_suite_config(self, project_test_suite_config):
        """Sets the project_test_suite_config of this ProjectProject.


        :param project_test_suite_config: The project_test_suite_config of this ProjectProject.  # noqa: E501
        :type: TestrunTestSuiteConfig
        """

        self._project_test_suite_config = project_test_suite_config

    @property
    def profiling_config(self):
        """Gets the profiling_config of this ProjectProject.  # noqa: E501


        :return: The profiling_config of this ProjectProject.  # noqa: E501
        :rtype: TestrunProfilingConfig
        """
        return self._profiling_config

    @profiling_config.setter
    def profiling_config(self, profiling_config):
        """Sets the profiling_config of this ProjectProject.


        :param profiling_config: The profiling_config of this ProjectProject.  # noqa: E501
        :type: TestrunProfilingConfig
        """

        self._profiling_config = profiling_config

    @property
    def run_time_info(self):
        """Gets the run_time_info of this ProjectProject.  # noqa: E501


        :return: The run_time_info of this ProjectProject.  # noqa: E501
        :rtype: RuntimeinfoRunTimeInfo
        """
        return self._run_time_info

    @run_time_info.setter
    def run_time_info(self, run_time_info):
        """Sets the run_time_info of this ProjectProject.


        :param run_time_info: The run_time_info of this ProjectProject.  # noqa: E501
        :type: RuntimeinfoRunTimeInfo
        """

        self._run_time_info = run_time_info

    @property
    def is_published(self):
        """Gets the is_published of this ProjectProject.  # noqa: E501

        Published projects are shown on the Workspace overview page.  # noqa: E501

        :return: The is_published of this ProjectProject.  # noqa: E501
        :rtype: bool
        """
        return self._is_published

    @is_published.setter
    def is_published(self, is_published):
        """Sets the is_published of this ProjectProject.

        Published projects are shown on the Workspace overview page.  # noqa: E501

        :param is_published: The is_published of this ProjectProject.  # noqa: E501
        :type: bool
        """

        self._is_published = is_published

    @property
    def last_test_run_time(self):
        """Gets the last_test_run_time of this ProjectProject.  # noqa: E501

        Last time a Test Run was successfully uploaded to the Project.  # noqa: E501

        :return: The last_test_run_time of this ProjectProject.  # noqa: E501
        :rtype: datetime
        """
        return self._last_test_run_time

    @last_test_run_time.setter
    def last_test_run_time(self, last_test_run_time):
        """Sets the last_test_run_time of this ProjectProject.

        Last time a Test Run was successfully uploaded to the Project.  # noqa: E501

        :param last_test_run_time: The last_test_run_time of this ProjectProject.  # noqa: E501
        :type: datetime
        """

        self._last_test_run_time = last_test_run_time

    @property
    def stress_test_categories(self):
        """Gets the stress_test_categories of this ProjectProject.  # noqa: E501

        List of test categories to be run in Stress Testing.  # noqa: E501

        :return: The stress_test_categories of this ProjectProject.  # noqa: E501
        :rtype: list[TestrunTestCategoryType]
        """
        return self._stress_test_categories

    @stress_test_categories.setter
    def stress_test_categories(self, stress_test_categories):
        """Sets the stress_test_categories of this ProjectProject.

        List of test categories to be run in Stress Testing.  # noqa: E501

        :param stress_test_categories: The stress_test_categories of this ProjectProject.  # noqa: E501
        :type: list[TestrunTestCategoryType]
        """

        self._stress_test_categories = stress_test_categories

    @property
    def continuous_test_categories(self):
        """Gets the continuous_test_categories of this ProjectProject.  # noqa: E501

        List of test categories to be run in Continuous Testing.  # noqa: E501

        :return: The continuous_test_categories of this ProjectProject.  # noqa: E501
        :rtype: list[TestrunTestCategoryType]
        """
        return self._continuous_test_categories

    @continuous_test_categories.setter
    def continuous_test_categories(self, continuous_test_categories):
        """Sets the continuous_test_categories of this ProjectProject.

        List of test categories to be run in Continuous Testing.  # noqa: E501

        :param continuous_test_categories: The continuous_test_categories of this ProjectProject.  # noqa: E501
        :type: list[TestrunTestCategoryType]
        """

        self._continuous_test_categories = continuous_test_categories

    @property
    def risk_scores(self):
        """Gets the risk_scores of this ProjectProject.  # noqa: E501


        :return: The risk_scores of this ProjectProject.  # noqa: E501
        :rtype: list[RiskscoreRiskScore]
        """
        return self._risk_scores

    @risk_scores.setter
    def risk_scores(self, risk_scores):
        """Sets the risk_scores of this ProjectProject.


        :param risk_scores: The risk_scores of this ProjectProject.  # noqa: E501
        :type: list[RiskscoreRiskScore]
        """

        self._risk_scores = risk_scores

    @property
    def active_schedule(self):
        """Gets the active_schedule of this ProjectProject.  # noqa: E501


        :return: The active_schedule of this ProjectProject.  # noqa: E501
        :rtype: ProjectScheduleInfo
        """
        return self._active_schedule

    @active_schedule.setter
    def active_schedule(self, active_schedule):
        """Sets the active_schedule of this ProjectProject.


        :param active_schedule: The active_schedule of this ProjectProject.  # noqa: E501
        :type: ProjectScheduleInfo
        """

        self._active_schedule = active_schedule

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProjectProject, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProjectProject):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class MonitorArtifactIdentifier(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'test_case_metric_identifier': 'ArtifactIdentifierTestCaseMetricIdentifier',
        'category_test_metric_identifier': 'ArtifactIdentifierCategoryTestIdentifier',
        'subset_test_metric_identifier': 'ArtifactIdentifierSubsetTestMetricIdentifier'
    }

    attribute_map = {
        'test_case_metric_identifier': 'testCaseMetricIdentifier',
        'category_test_metric_identifier': 'categoryTestMetricIdentifier',
        'subset_test_metric_identifier': 'subsetTestMetricIdentifier'
    }

    def __init__(self, test_case_metric_identifier=None, category_test_metric_identifier=None, subset_test_metric_identifier=None):  # noqa: E501
        """MonitorArtifactIdentifier - a model defined in Swagger"""  # noqa: E501
        self._test_case_metric_identifier = None
        self._category_test_metric_identifier = None
        self._subset_test_metric_identifier = None
        self.discriminator = None
        if test_case_metric_identifier is not None:
            self.test_case_metric_identifier = test_case_metric_identifier
        if category_test_metric_identifier is not None:
            self.category_test_metric_identifier = category_test_metric_identifier
        if subset_test_metric_identifier is not None:
            self.subset_test_metric_identifier = subset_test_metric_identifier

    @property
    def test_case_metric_identifier(self):
        """Gets the test_case_metric_identifier of this MonitorArtifactIdentifier.  # noqa: E501


        :return: The test_case_metric_identifier of this MonitorArtifactIdentifier.  # noqa: E501
        :rtype: ArtifactIdentifierTestCaseMetricIdentifier
        """
        return self._test_case_metric_identifier

    @test_case_metric_identifier.setter
    def test_case_metric_identifier(self, test_case_metric_identifier):
        """Sets the test_case_metric_identifier of this MonitorArtifactIdentifier.


        :param test_case_metric_identifier: The test_case_metric_identifier of this MonitorArtifactIdentifier.  # noqa: E501
        :type: ArtifactIdentifierTestCaseMetricIdentifier
        """

        self._test_case_metric_identifier = test_case_metric_identifier

    @property
    def category_test_metric_identifier(self):
        """Gets the category_test_metric_identifier of this MonitorArtifactIdentifier.  # noqa: E501


        :return: The category_test_metric_identifier of this MonitorArtifactIdentifier.  # noqa: E501
        :rtype: ArtifactIdentifierCategoryTestIdentifier
        """
        return self._category_test_metric_identifier

    @category_test_metric_identifier.setter
    def category_test_metric_identifier(self, category_test_metric_identifier):
        """Sets the category_test_metric_identifier of this MonitorArtifactIdentifier.


        :param category_test_metric_identifier: The category_test_metric_identifier of this MonitorArtifactIdentifier.  # noqa: E501
        :type: ArtifactIdentifierCategoryTestIdentifier
        """

        self._category_test_metric_identifier = category_test_metric_identifier

    @property
    def subset_test_metric_identifier(self):
        """Gets the subset_test_metric_identifier of this MonitorArtifactIdentifier.  # noqa: E501


        :return: The subset_test_metric_identifier of this MonitorArtifactIdentifier.  # noqa: E501
        :rtype: ArtifactIdentifierSubsetTestMetricIdentifier
        """
        return self._subset_test_metric_identifier

    @subset_test_metric_identifier.setter
    def subset_test_metric_identifier(self, subset_test_metric_identifier):
        """Sets the subset_test_metric_identifier of this MonitorArtifactIdentifier.


        :param subset_test_metric_identifier: The subset_test_metric_identifier of this MonitorArtifactIdentifier.  # noqa: E501
        :type: ArtifactIdentifierSubsetTestMetricIdentifier
        """

        self._subset_test_metric_identifier = subset_test_metric_identifier

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MonitorArtifactIdentifier, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MonitorArtifactIdentifier):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TestrunresultTestBatchResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'test_run_id': 'str',
        'test_type': 'str',
        'test_name': 'str',
        'description': 'str',
        'test_category': 'TestrunTestCategoryType',
        'category': 'str',
        'duration_in_millis': 'str',
        'severity': 'RimeSeverity',
        'summary_counts': 'TestrunresultResultSummaryCounts',
        'failing_features': 'list[str]',
        'metrics': 'list[RimeTestMetric]',
        'show_in_test_comparisons': 'bool',
        'display': 'TestrunresultTestBatchResultDisplay',
        'failing_rows_result': 'RimeFailingRowsResult',
        'security_test_details': 'DetectionSecurityEventDetails'
    }

    attribute_map = {
        'test_run_id': 'testRunId',
        'test_type': 'testType',
        'test_name': 'testName',
        'description': 'description',
        'test_category': 'testCategory',
        'category': 'category',
        'duration_in_millis': 'durationInMillis',
        'severity': 'severity',
        'summary_counts': 'summaryCounts',
        'failing_features': 'failingFeatures',
        'metrics': 'metrics',
        'show_in_test_comparisons': 'showInTestComparisons',
        'display': 'display',
        'failing_rows_result': 'failingRowsResult',
        'security_test_details': 'securityTestDetails'
    }

    def __init__(self, test_run_id=None, test_type=None, test_name=None, description=None, test_category=None, category=None, duration_in_millis=None, severity=None, summary_counts=None, failing_features=None, metrics=None, show_in_test_comparisons=None, display=None, failing_rows_result=None, security_test_details=None):  # noqa: E501
        """TestrunresultTestBatchResult - a model defined in Swagger"""  # noqa: E501
        self._test_run_id = None
        self._test_type = None
        self._test_name = None
        self._description = None
        self._test_category = None
        self._category = None
        self._duration_in_millis = None
        self._severity = None
        self._summary_counts = None
        self._failing_features = None
        self._metrics = None
        self._show_in_test_comparisons = None
        self._display = None
        self._failing_rows_result = None
        self._security_test_details = None
        self.discriminator = None
        if test_run_id is not None:
            self.test_run_id = test_run_id
        if test_type is not None:
            self.test_type = test_type
        if test_name is not None:
            self.test_name = test_name
        if description is not None:
            self.description = description
        if test_category is not None:
            self.test_category = test_category
        if category is not None:
            self.category = category
        if duration_in_millis is not None:
            self.duration_in_millis = duration_in_millis
        if severity is not None:
            self.severity = severity
        if summary_counts is not None:
            self.summary_counts = summary_counts
        if failing_features is not None:
            self.failing_features = failing_features
        if metrics is not None:
            self.metrics = metrics
        if show_in_test_comparisons is not None:
            self.show_in_test_comparisons = show_in_test_comparisons
        if display is not None:
            self.display = display
        if failing_rows_result is not None:
            self.failing_rows_result = failing_rows_result
        if security_test_details is not None:
            self.security_test_details = security_test_details

    @property
    def test_run_id(self):
        """Gets the test_run_id of this TestrunresultTestBatchResult.  # noqa: E501

        Uniquely specifies a parent Test Run.  # noqa: E501

        :return: The test_run_id of this TestrunresultTestBatchResult.  # noqa: E501
        :rtype: str
        """
        return self._test_run_id

    @test_run_id.setter
    def test_run_id(self, test_run_id):
        """Sets the test_run_id of this TestrunresultTestBatchResult.

        Uniquely specifies a parent Test Run.  # noqa: E501

        :param test_run_id: The test_run_id of this TestrunresultTestBatchResult.  # noqa: E501
        :type: str
        """

        self._test_run_id = test_run_id

    @property
    def test_type(self):
        """Gets the test_type of this TestrunresultTestBatchResult.  # noqa: E501


        :return: The test_type of this TestrunresultTestBatchResult.  # noqa: E501
        :rtype: str
        """
        return self._test_type

    @test_type.setter
    def test_type(self, test_type):
        """Sets the test_type of this TestrunresultTestBatchResult.


        :param test_type: The test_type of this TestrunresultTestBatchResult.  # noqa: E501
        :type: str
        """

        self._test_type = test_type

    @property
    def test_name(self):
        """Gets the test_name of this TestrunresultTestBatchResult.  # noqa: E501

        The display-friendly name; for example: 'Categorical Feature Drift'.  # noqa: E501

        :return: The test_name of this TestrunresultTestBatchResult.  # noqa: E501
        :rtype: str
        """
        return self._test_name

    @test_name.setter
    def test_name(self, test_name):
        """Sets the test_name of this TestrunresultTestBatchResult.

        The display-friendly name; for example: 'Categorical Feature Drift'.  # noqa: E501

        :param test_name: The test_name of this TestrunresultTestBatchResult.  # noqa: E501
        :type: str
        """

        self._test_name = test_name

    @property
    def description(self):
        """Gets the description of this TestrunresultTestBatchResult.  # noqa: E501

        The description of the test. Note: this is currently identical to the display.description_html field.  # noqa: E501

        :return: The description of this TestrunresultTestBatchResult.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this TestrunresultTestBatchResult.

        The description of the test. Note: this is currently identical to the display.description_html field.  # noqa: E501

        :param description: The description of this TestrunresultTestBatchResult.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def test_category(self):
        """Gets the test_category of this TestrunresultTestBatchResult.  # noqa: E501


        :return: The test_category of this TestrunresultTestBatchResult.  # noqa: E501
        :rtype: TestrunTestCategoryType
        """
        return self._test_category

    @test_category.setter
    def test_category(self, test_category):
        """Sets the test_category of this TestrunresultTestBatchResult.


        :param test_category: The test_category of this TestrunresultTestBatchResult.  # noqa: E501
        :type: TestrunTestCategoryType
        """

        self._test_category = test_category

    @property
    def category(self):
        """Gets the category of this TestrunresultTestBatchResult.  # noqa: E501

        The string field `category` is deprecated in v2.1 and will be removed in v2.3. Please use the enum field test_category instead, which provides the same info.  # noqa: E501

        :return: The category of this TestrunresultTestBatchResult.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this TestrunresultTestBatchResult.

        The string field `category` is deprecated in v2.1 and will be removed in v2.3. Please use the enum field test_category instead, which provides the same info.  # noqa: E501

        :param category: The category of this TestrunresultTestBatchResult.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def duration_in_millis(self):
        """Gets the duration_in_millis of this TestrunresultTestBatchResult.  # noqa: E501

        The duration of the test run.  # noqa: E501

        :return: The duration_in_millis of this TestrunresultTestBatchResult.  # noqa: E501
        :rtype: str
        """
        return self._duration_in_millis

    @duration_in_millis.setter
    def duration_in_millis(self, duration_in_millis):
        """Sets the duration_in_millis of this TestrunresultTestBatchResult.

        The duration of the test run.  # noqa: E501

        :param duration_in_millis: The duration_in_millis of this TestrunresultTestBatchResult.  # noqa: E501
        :type: str
        """

        self._duration_in_millis = duration_in_millis

    @property
    def severity(self):
        """Gets the severity of this TestrunresultTestBatchResult.  # noqa: E501


        :return: The severity of this TestrunresultTestBatchResult.  # noqa: E501
        :rtype: RimeSeverity
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """Sets the severity of this TestrunresultTestBatchResult.


        :param severity: The severity of this TestrunresultTestBatchResult.  # noqa: E501
        :type: RimeSeverity
        """

        self._severity = severity

    @property
    def summary_counts(self):
        """Gets the summary_counts of this TestrunresultTestBatchResult.  # noqa: E501


        :return: The summary_counts of this TestrunresultTestBatchResult.  # noqa: E501
        :rtype: TestrunresultResultSummaryCounts
        """
        return self._summary_counts

    @summary_counts.setter
    def summary_counts(self, summary_counts):
        """Sets the summary_counts of this TestrunresultTestBatchResult.


        :param summary_counts: The summary_counts of this TestrunresultTestBatchResult.  # noqa: E501
        :type: TestrunresultResultSummaryCounts
        """

        self._summary_counts = summary_counts

    @property
    def failing_features(self):
        """Gets the failing_features of this TestrunresultTestBatchResult.  # noqa: E501

        The list of failing features.  # noqa: E501

        :return: The failing_features of this TestrunresultTestBatchResult.  # noqa: E501
        :rtype: list[str]
        """
        return self._failing_features

    @failing_features.setter
    def failing_features(self, failing_features):
        """Sets the failing_features of this TestrunresultTestBatchResult.

        The list of failing features.  # noqa: E501

        :param failing_features: The failing_features of this TestrunresultTestBatchResult.  # noqa: E501
        :type: list[str]
        """

        self._failing_features = failing_features

    @property
    def metrics(self):
        """Gets the metrics of this TestrunresultTestBatchResult.  # noqa: E501


        :return: The metrics of this TestrunresultTestBatchResult.  # noqa: E501
        :rtype: list[RimeTestMetric]
        """
        return self._metrics

    @metrics.setter
    def metrics(self, metrics):
        """Sets the metrics of this TestrunresultTestBatchResult.


        :param metrics: The metrics of this TestrunresultTestBatchResult.  # noqa: E501
        :type: list[RimeTestMetric]
        """

        self._metrics = metrics

    @property
    def show_in_test_comparisons(self):
        """Gets the show_in_test_comparisons of this TestrunresultTestBatchResult.  # noqa: E501

        A Boolean that specifies whether to include the test batch in the test comparison page in the web UI. This field is no longer used, and will be removed in 2.3.  # noqa: E501

        :return: The show_in_test_comparisons of this TestrunresultTestBatchResult.  # noqa: E501
        :rtype: bool
        """
        return self._show_in_test_comparisons

    @show_in_test_comparisons.setter
    def show_in_test_comparisons(self, show_in_test_comparisons):
        """Sets the show_in_test_comparisons of this TestrunresultTestBatchResult.

        A Boolean that specifies whether to include the test batch in the test comparison page in the web UI. This field is no longer used, and will be removed in 2.3.  # noqa: E501

        :param show_in_test_comparisons: The show_in_test_comparisons of this TestrunresultTestBatchResult.  # noqa: E501
        :type: bool
        """

        self._show_in_test_comparisons = show_in_test_comparisons

    @property
    def display(self):
        """Gets the display of this TestrunresultTestBatchResult.  # noqa: E501


        :return: The display of this TestrunresultTestBatchResult.  # noqa: E501
        :rtype: TestrunresultTestBatchResultDisplay
        """
        return self._display

    @display.setter
    def display(self, display):
        """Sets the display of this TestrunresultTestBatchResult.


        :param display: The display of this TestrunresultTestBatchResult.  # noqa: E501
        :type: TestrunresultTestBatchResultDisplay
        """

        self._display = display

    @property
    def failing_rows_result(self):
        """Gets the failing_rows_result of this TestrunresultTestBatchResult.  # noqa: E501


        :return: The failing_rows_result of this TestrunresultTestBatchResult.  # noqa: E501
        :rtype: RimeFailingRowsResult
        """
        return self._failing_rows_result

    @failing_rows_result.setter
    def failing_rows_result(self, failing_rows_result):
        """Sets the failing_rows_result of this TestrunresultTestBatchResult.


        :param failing_rows_result: The failing_rows_result of this TestrunresultTestBatchResult.  # noqa: E501
        :type: RimeFailingRowsResult
        """

        self._failing_rows_result = failing_rows_result

    @property
    def security_test_details(self):
        """Gets the security_test_details of this TestrunresultTestBatchResult.  # noqa: E501


        :return: The security_test_details of this TestrunresultTestBatchResult.  # noqa: E501
        :rtype: DetectionSecurityEventDetails
        """
        return self._security_test_details

    @security_test_details.setter
    def security_test_details(self, security_test_details):
        """Sets the security_test_details of this TestrunresultTestBatchResult.


        :param security_test_details: The security_test_details of this TestrunresultTestBatchResult.  # noqa: E501
        :type: DetectionSecurityEventDetails
        """

        self._security_test_details = security_test_details

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TestrunresultTestBatchResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TestrunresultTestBatchResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
